# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from gestionatr.output.messages.sw_c1 import *
from gestionatr.output.messages.base import rep_cut


# Paso 01
class MensajeCambiodeComercializadorConCambios(XmlModel):
    _sort_order = ('mensaje', 'cabecera', 'cambiode_comercializador_con_cambios')

    def __init__(self):
        self.doc_root = None
        self.mensaje = XmlField(
            'MensajeCambiodeComercializadorConCambios',
            attributes={'xmlns': 'http://localhost/elegibilidad'}
        )
        self.cabecera = Cabecera()
        self.cambiode_comercializador_con_cambios = CambiodeComercializadorConCambios()
        super(MensajeCambiodeComercializadorConCambios, self).__init__(
            'MensajeCambiodeComercializadorConCambios', 'mensaje'
        )


class CambiodeComercializadorConCambios(XmlModel):

    _sort_order = ('cambiode_comercializador_con_cambios', 'datos_solicitud', 'contrato', 'cliente', 'medida', 'doc_tecnica', 'comentarios', 'registros_documento')

    def __init__(self):
        self.cambiode_comercializador_con_cambios = XmlField('CambiodeComercializadorConCambios')
        self.datos_solicitud = DatosSolicitud()
        self.contrato = Contrato()
        self.cliente = Cliente()
        self.medida = MedidaResto()
        self.doc_tecnica = DocTecnica()
        self.comentarios = XmlField('Comentarios')
        self.registros_documento = RegistrosDocumento()
        super(CambiodeComercializadorConCambios, self).__init__('CambiodeComercializadorConCambios', 'cambiode_comercializador_con_cambios')


class DatosSolicitud(DatosSolicitud):

    _sort_order = ('datos_solicitud', 'tipo_modificacion', 'tipo_solicitud_administrativa', 'cnae', 'ind_esencial',
                   'fecha_ultimo_movimiento_ind_esencial', 'ind_activacion', 'fecha_prevista_accion',
                   'contratacion_incondicional_ps', 'contratacion_incondicional_bs', 'bono_social',
                   'solicitud_tension', 'tension_solicitada')

    def __init__(self):
        super(DatosSolicitud, self).__init__()
        self.tipo_modificacion = XmlField('TipoModificacion')
        self.tipo_solicitud_administrativa = XmlField('TipoSolicitudAdministrativa')
        self.cnae = XmlField('CNAE')
        self.tension_solicitada = XmlField('TensionSolicitada')


class Contrato(Contrato):

    _sort_order = ('contrato', 'id_contrato', 'fecha_finalizacion', 'autoconsumo', 'tipo_contrato_atr',
                   'cups_principal', 'condiciones_contractuales', 'periodicidad_facturacion',
                   'consumo_anual_estimado', 'contacto', 'tipo_activacion_prevista', 'fecha_activacion_prevista')

    def __init__(self):
        super(Contrato, self).__init__()
        self.fecha_finalizacion = XmlField('FechaFinalizacion')
        self.autoconsumo = Autoconsumo()
        self.tipo_contrato_atr = XmlField('TipoContratoATR')
        self.cups_principal = XmlField('CUPSPrincipal')
        self.periodicidad_facturacion = XmlField('PeriodicidadFacturacion')
        self.consumo_anual_estimado = XmlField('ConsumoAnualEstimado')
        self.contacto = Contacto()


class Contacto(XmlModel):

    _sort_order = ('contacto', 'persona_de_contacto', 'telefonos', 'correo_electronico')

    def __init__(self):
        self.contacto = XmlField('Contacto')
        self.persona_de_contacto = XmlField('PersonaDeContacto')
        self.telefonos = []
        self.correo_electronico = XmlField('CorreoElectronico')
        super(Contacto, self).__init__('Contacto', 'contacto')


class Cliente(Cliente):

    _sort_order = ('cliente', 'id_cliente', 'nombre', 'telefonos', 'correo_electronico', 'indicador_tipo_direccion', 'direccion')

    def __init__(self):
        super(Cliente, self).__init__()
        self.indicador_tipo_direccion = XmlField('IndicadorTipoDireccion')
        self.direccion = Direccion()


class Direccion(XmlModel):

    _sort_order = ('direccion', 'pais', 'provincia', 'municipio', 'poblacion', 'cod_postal', 'via', 'apartado_de_correos')

    def __init__(self, name='Direccion'):
        self.direccion = XmlField(name)
        self.pais = XmlField('Pais')
        self.provincia = XmlField('Provincia')
        self.municipio = XmlField('Municipio')
        self.poblacion = XmlField('Poblacion')
        self.cod_postal = XmlField('CodPostal')
        self.via = Via()
        self.apartado_de_correos = XmlField('ApartadoDeCorreos')
        super(Direccion, self).__init__(name, 'direccion')


class Via(XmlModel):

    _sort_order = ('via', 'tipo_via', 'calle', 'numero_finca', 'duplicador_finca', 'escalera', 'piso', 'puerta', 'tipo_aclarador_finca', 'aclarador_finca')

    def __init__(self, name='Via'):
        self.via = XmlField(name)
        self.tipo_via = XmlField('TipoVia')
        self.calle = XmlField('Calle', rep=rep_cut(30))
        self.numero_finca = XmlField('NumeroFinca', rep=rep_cut(5))
        self.duplicador_finca = XmlField('DuplicadorFinca', rep=rep_cut(3))
        self.escalera = XmlField('Escalera', rep=rep_cut(3))
        self.piso = XmlField('Piso', rep=rep_cut(3))
        self.puerta = XmlField('Puerta', rep=rep_cut(3))
        self.tipo_aclarador_finca = XmlField(
            'TipoAclaradorFinca', rep=rep_cut(2)
        )
        self.aclarador_finca = XmlField('AclaradorFinca', rep=rep_cut(40))
        super(Via, self).__init__(name, 'via')


class MedidaResto(XmlModel):

    _sort_order = ('medida_resto', 'propiedad_equipo', 'tipo_equipo_medida', 'modelos_aparato')

    def __init__(self):
        self.medida_resto = XmlField('Medida')
        self.propiedad_equipo = XmlField('PropiedadEquipo')
        self.tipo_equipo_medida = XmlField('TipoEquipoMedida')
        self.modelos_aparato = ModelosAparato()
        super(MedidaResto, self).__init__('medida_resto', 'medida_resto')


class ModelosAparato(XmlModel):

    _sort_order = ('modelos_aparato', 'modelo_aparato_list')

    def __init__(self):
        self.modelos_aparato = XmlField('ModelosAparato')
        self.modelo_aparato_list = []
        super(ModelosAparato, self).__init__('ModelosAparato', 'modelos_aparato')


class ModeloAparato(XmlModel):

    _sort_order = ('modelo_aparato', 'tipo_aparato', 'marca_aparato', 'modelo_marca')

    def __init__(self):
        self.modelo_aparato = XmlField('ModeloAparato')
        self.tipo_aparato = XmlField('TipoAparato')
        self.marca_aparato = XmlField('MarcaAparato')
        self.modelo_marca = XmlField('ModeloMarca')
        super(ModeloAparato, self).__init__('ModeloAparato', 'modelo_aparato')


class DocTecnica(XmlModel):

    _sort_order = ('doc_tecnica', 'datos_cie', 'datos_apm')

    def __init__(self):
        self.doc_tecnica = XmlField('DocTecnica')
        self.datos_cie = DatosCie()
        self.datos_apm = DatosAPM()
        super(DocTecnica, self).__init__('DocTecnica', 'doc_tecnica')


class DatosCie(XmlModel):

    _sort_order = ('datos_cie', 'cie_papel', 'cie_electronico', 'validez_cie', 'potencia_no_interrumpible')

    def __init__(self):
        self.datos_cie = XmlField('DatosCie')
        self.cie_papel = CIEPapel()
        self.cie_electronico = CIEElectronico()
        self.validez_cie = XmlField('ValidezCIE')
        self.potencia_no_interrumpible = XmlField('PotenciaNoInterrumpible')
        super(DatosCie, self).__init__('DatosCie', 'datos_cie')


class CIEPapel(XmlModel):

    _sort_order = ('cie_papel', 'codigo_cie', 'potencia_inst_bt', 'fecha_emision_cie', 'fecha_caducidad_cie', 'nif_instalador', 'codigo_instalador', 'tension_suministro_cie', 'tipo_suministro')

    def __init__(self):
        self.cie_papel = XmlField('CIEPapel')
        self.codigo_cie = XmlField('CodigoCie')
        self.potencia_inst_bt = XmlField('PotenciaInstBT')
        self.fecha_emision_cie = XmlField('FechaEmisionCie')
        self.fecha_caducidad_cie = XmlField('FechaCaducidadCie')
        self.nif_instalador = XmlField('NifInstalador')
        self.codigo_instalador = XmlField('CodigoInstalador')
        self.tension_suministro_cie = XmlField('TensionSuministroCIE')
        self.tipo_suministro = XmlField('TipoSuministro')
        super(CIEPapel, self).__init__('CIEPapel', 'cie_papel')


class CIEElectronico(XmlModel):

    _sort_order = ('cie_electronico', 'codigo_cie', 'sello_electronico')

    def __init__(self):
        self.cie_electronico = XmlField('CIEElectronico')
        self.codigo_cie = XmlField('CodigoCie')
        self.sello_electronico = XmlField('SelloElectronico')
        super(CIEElectronico, self).__init__('CIEElectronico', 'cie_electronico')


class DatosAPM(XmlModel):

    _sort_order = ('datos_apm', 'codigo_apm', 'potencia_inst_at', 'fecha_emision_apm', 'fecha_caducidad_apm', 'tension_suministro_apm', 'nif_instalador', 'codigo_instalador')

    def __init__(self):
        self.datos_apm = XmlField('DatosAPM')
        self.codigo_apm = XmlField('CodigoApm')
        self.potencia_inst_at = XmlField('PotenciaInstAT')
        self.fecha_emision_apm = XmlField('FechaEmisionApm')
        self.fecha_caducidad_apm = XmlField('FechaCaducidadApm')
        self.tension_suministro_apm = XmlField('TensionSuministroAPM')
        self.nif_instalador = XmlField('NifInstalador')
        self.codigo_instalador = XmlField('CodigoInstalador')
        super(DatosAPM, self).__init__('DatosAPM', 'datos_apm')


# Paso 02
class MensajeAceptacionCambiodeComercializadorConCambios(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'aceptacion_cambiode_comercializador_con_cambios')

    def __init__(self):
        self.mensaje = XmlField('MensajeAceptacionCambiodeComercializadorConCambios',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.aceptacion_cambiode_comercializador_con_cambios = AceptacionCambiodeComercializadorConCambios()
        super(MensajeAceptacionCambiodeComercializadorConCambios, self).__init__('MensajeAceptacionCambiodeComercializadorConCambios', 'mensaje')


class AceptacionCambiodeComercializadorConCambios(XmlModel):

    _sort_order = ('aceptacion_cambiode_comercializador_con_cambios', 'datos_aceptacion', 'contrato')

    def __init__(self):
        self.aceptacion_cambiode_comercializador_con_cambios = XmlField('AceptacionCambiodeComercializadorConCambios')
        self.datos_aceptacion = DatosAceptacion()
        self.contrato = Contrato()
        super(AceptacionCambiodeComercializadorConCambios, self).__init__('AceptacionCambiodeComercializadorConCambios', 'aceptacion_cambiode_comercializador_con_cambios')


# Paso 03
class MensajeIncidenciasATRDistribuidor(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'incidencias_atr_distribuidor')

    def __init__(self):
        self.mensaje = XmlField('MensajeIncidenciasATRDistribuidor',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.incidencias_atr_distribuidor = IncidenciasATRDistribuidor()
        super(MensajeIncidenciasATRDistribuidor, self).__init__('MensajeIncidenciasATRDistribuidor', 'mensaje')


class IncidenciasATRDistribuidor(XmlModel):

    _sort_order = ('incidencias_atr_distribuidor', 'fecha_incidencia', 'fecha_prevista_accion', 'incidencia_list')

    def __init__(self):
        self.incidencias_atr_distribuidor = XmlField('IncidenciasATRDistribuidor')
        self.fecha_incidencia = XmlField('FechaIncidencia')
        self.fecha_prevista_accion = XmlField('FechaPrevistaAccion')
        self.incidencia_list = []
        super(IncidenciasATRDistribuidor, self).__init__('IncidenciasATRDistribuidor', 'incidencias_atr_distribuidor')


class Incidencia(XmlModel):

    _sort_order = ('incidencia', 'secuencial', 'codigo_motivo', 'comentarios')

    def __init__(self):
        self.incidencia = XmlField('Incidencia')
        self.secuencial = XmlField('Secuencial')
        self.codigo_motivo = XmlField('CodigoMotivo')
        self.comentarios = XmlField('Comentarios')
        super(Incidencia, self).__init__('Incidencia', 'incidencia')


# Paso 04 -> C1
# Paso 05
class MensajeActivacionCambiodeComercializadorConCambios(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'activacion_cambiode_comercializador_con_cambios')

    def __init__(self):
        self.mensaje = XmlField('MensajeActivacionCambiodeComercializadorConCambios',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.activacion_cambiode_comercializador_con_cambios = ActivacionCambiodeComercializadorConCambios()
        super(MensajeActivacionCambiodeComercializadorConCambios, self).__init__('MensajeActivacionCambiodeComercializadorConCambios', 'mensaje')


class ActivacionCambiodeComercializadorConCambios(XmlModel):

    _sort_order = ('activacion_cambiode_comercializador_con_cambios', 'datos_activacion', 'contrato',
                   'puntos_de_medida', 'registros_documento')

    def __init__(self):
        self.activacion_cambiode_comercializador_con_cambios = XmlField('ActivacionCambiodeComercializadorConCambios')
        self.datos_activacion = DatosActivacion()
        self.contrato = Contrato()
        self.puntos_de_medida = PuntosDeMedida()
        self.registros_documento = RegistrosDocumento()
        super(ActivacionCambiodeComercializadorConCambios, self).__init__('ActivacionCambiodeComercializadorConCambios', 'activacion_cambiode_comercializador_con_cambios')


# Paso 06
class MensajeActivacionComercializadorSaliente(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'notificacion_comercializador_saliente')

    def __init__(self):
        self.mensaje = XmlField('MensajeActivacionComercializadorSaliente',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.notificacion_comercializador_saliente = NotificacionComercializadorSaliente()
        super(MensajeActivacionComercializadorSaliente, self).__init__('MensajeActivacionComercializadorSaliente', 'mensaje')


class NotificacionComercializadorSaliente(XmlModel):

    _sort_order = ('notificacion_comercializador_saliente', 'datos_notificacion', 'contrato', 'puntos_de_medida')

    def __init__(self):
        self.notificacion_comercializador_saliente = XmlField('NotificacionComercializadorSaliente')
        self.datos_notificacion = DatosNotificacion()
        self.contrato = Contrato()
        self.puntos_de_medida = PuntosDeMedida()
        super(NotificacionComercializadorSaliente, self).__init__('NotificacionComercializadorSaliente', 'notificacion_comercializador_saliente')

# Paso 08 -> C1 MensajeAnulacionSolicitud
# Paso 09 -> C1 MensajeAceptacionAnulacion
# Paso 10 -> C1 MensajeAceptacionAnulacion
# Paso 11 -> C1 MensajeAceptacionCambiodeComercializadorSaliente
# Paso 12 -> C1 MensajeRechazoCambiodeComercializadorSaliente


# Paso 13
class MensajeContestacionIncidencia(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'contestacion_incidencia')

    def __init__(self):
        self.mensaje = XmlField('MensajeContestacionIncidencia',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.contestacion_incidencia = ContestacionIncidencia()
        super(MensajeContestacionIncidencia, self).__init__('MensajeContestacionIncidencia', 'mensaje')


class ContestacionIncidencia(XmlModel):

    _sort_order = ('contestacion_incidencia_node', 'contestacion_incidencia', 'contacto')

    def __init__(self):
        self.contestacion_incidencia_node = XmlField('ContestacionIncidencia')
        self.contestacion_incidencia = XmlField('ContestacionIncidencia')
        self.contacto = Contacto()
        super(ContestacionIncidencia, self).__init__('ContestacionIncidencia', 'contestacion_incidencia_node')



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from .message_gas import MessageGas
from .Deadlines import ProcessDeadline
from gestionatr.utils import get_rec_attr


class A5_29(MessageGas, ProcessDeadline):

    # Datos paso a529
    # TODO

    # Datos paso a629

    @property
    def codrpds(self):
        tree = '{0}.codrpds'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def fechacreacion(self):
        tree = '{0}.fechacreacion'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def horacreacion(self):
        tree = '{0}.horacreacion'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def codresultado(self):
        tree = '{0}.codresultado'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def descresultado(self):
        tree = '{0}.descresultado'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def codmotivo(self):
        tree = '{0}.codmotivo'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def descmotresultado(self):
        tree = '{0}.descmotresultado'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def resvalidacioncliente(self):
        tree = '{0}.resvalidacioncliente'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def datosdis(self):
        tree = '{0}.datosdis'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return DatosDis(data)
        else:
            return False

    @property
    def datoscom(self):
        tree = '{0}.datoscom'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return DatosCom(data)
        else:
            return False


class DatosDis(object):
    def __init__(self, data):
        self.datosdis = data

    @property
    def cups(self):
        data = False
        try:
            data = self.datosdis.cups.text
        except AttributeError:
            pass
        return data

    @property
    def distribuidor(self):
        data = False
        try:
            data = self.datosdis.distribuidor.text
        except AttributeError:
            pass
        return data

    @property
    def razonsocial(self):
        data = False
        try:
            data = self.datosdis.razonsocial.text
        except AttributeError:
            pass
        return data

    @property
    def codprovincia(self):
        data = False
        try:
            data = self.datosdis.codprovincia.text
        except AttributeError:
            pass
        return data

    @property
    def descprovincia(self):
        data = False
        try:
            data = self.datosdis.descprovincia.text
        except AttributeError:
            pass
        return data

    @property
    def codpostal(self):
        data = False
        try:
            data = self.datosdis.codpostal.text
        except AttributeError:
            pass
        return data

    @property
    def codmunicipio(self):
        data = False
        try:
            data = self.datosdis.codmunicipio.text
        except AttributeError:
            pass
        return data

    @property
    def descmunicipio(self):
        data = False
        try:
            data = self.datosdis.descmunicipio.text
        except AttributeError:
            pass
        return data

    @property
    def tipovia(self):
        data = False
        try:
            data = self.datosdis.tipovia.text
        except AttributeError:
            pass
        return data

    @property
    def via(self):
        data = False
        try:
            data = self.datosdis.via.text
        except AttributeError:
            pass
        return data

    @property
    def numfinca(self):
        data = False
        try:
            data = self.datosdis.numfinca.text
        except AttributeError:
            pass
        return data

    @property
    def restodireccion(self):
        data = False
        try:
            data = self.datosdis.restodireccion.text
        except AttributeError:
            pass
        return data

    @property
    def viviendahabitual(self):
        data = False
        try:
            data = self.datosdis.viviendahabitual.text
        except AttributeError:
            pass
        return data

    @property
    def fechaalta(self):
        data = False
        try:
            data = self.datosdis.fechaalta.text
        except AttributeError:
            pass
        return data

    @property
    def fechaultimalectura(self):
        data = False
        try:
            data = self.datosdis.fechaultimalectura.text
        except AttributeError:
            pass
        return data

    @property
    def puntocortado(self):
        data = False
        try:
            data = self.datosdis.puntocortado.text
        except AttributeError:
            pass
        return data

    @property
    def rangopresiondiseno(self):
        data = False
        try:
            data = self.datosdis.rangopresiondiseno.text
        except AttributeError:
            pass
        return data

    @property
    def qh(self):
        data = False
        try:
            data = self.datosdis.qh.text
        except AttributeError:
            pass
        return data

    @property
    def qmax(self):
        data = False
        try:
            data = self.datosdis.qmax.text
        except AttributeError:
            pass
        return data

    @property
    def derechotur(self):
        data = False
        try:
            data = self.datosdis.derechotur.text
        except AttributeError:
            pass
        return data

    @property
    def tarifapeaje(self):
        data = False
        try:
            data = self.datosdis.tarifapeaje.text
        except AttributeError:
            pass
        return data

    @property
    def fechaultimainspeccion(self):
        data = False
        try:
            data = self.datosdis.fechaultimainspeccion.text
        except AttributeError:
            pass
        return data

    @property
    def resultimainspeccion(self):
        data = False
        try:
            data = self.datosdis.resultimainspeccion.text
        except AttributeError:
            pass
        return data

    @property
    def fechaultimarevision(self):
        data = False
        try:
            data = self.datosdis.fechaultimarevision.text
        except AttributeError:
            pass
        return data

    @property
    def resultimarevision(self):
        data = False
        try:
            data = self.datosdis.resultimarevision.text
        except AttributeError:
            pass
        return data

    @property
    def historicoConsumo(self):
        data = []
        obj = get_rec_attr(self.obj, self._header, False)
        if hasattr(obj, 'historicoConsumo'):
            for i in self.datosdis.historicoConsumo:
                data.append(HistoricoConsumo(i))
            return data
        return data

    @property
    def pctjeconsumonoct(self):
        data = False
        try:
            data = self.datosdis.pctjeconsumonoct.text
        except AttributeError:
            pass
        return data

    @property
    def codequipo(self):
        data = False
        try:
            data = self.datosdis.codequipo.text
        except AttributeError:
            pass
        return data

    @property
    def contelemedida(self):
        data = False
        try:
            data = self.datosdis.contelemedida.text
        except AttributeError:
            pass
        return data

    @property
    def marcamodelocont(self):
        data = False
        try:
            data = self.datosdis.marcamodelocont.text
        except AttributeError:
            pass
        return data

    @property
    def marcamodelocorr(self):
        data = False
        try:
            data = self.datosdis.marcamodelocorr.text
        except AttributeError:
            pass
        return data

    @property
    def propiedad(self):
        data = False
        try:
            data = self.datosdis.propiedad.text
        except AttributeError:
            pass
        return data

    @property
    def tipocorrector(self):
        data = False
        try:
            data = self.datosdis.tipocorrector.text
        except AttributeError:
            pass
        return data

    @property
    def fecultcambiotarifa(self):
        data = False
        try:
            data = self.datosdis.fecultcambiotarifa.text
        except AttributeError:
            pass
        return data

    @property
    def fecultcontrato(self):
        data = False
        try:
            data = self.datosdis.fecultcontrato.text
        except AttributeError:
            pass
        return data

    @property
    def fecultcambiocom(self):
        data = False
        try:
            data = self.datosdis.fecultcambiocom.text
        except AttributeError:
            pass
        return data

    @property
    def perfil(self):
        data = False
        try:
            data = self.datosdis.perfil.text
        except AttributeError:
            pass
        return data

    @property
    def indconectadoplantasatelite(self):
        data = False
        try:
            data = self.datosdis.indconectadoplantasatelite.text
        except AttributeError:
            pass
        return data

    @property
    def cnae(self):
        data = False
        try:
            data = self.datosdis.cnae.text
        except AttributeError:
            pass
        return data

    @property
    def protectedtype(self):
        data = False
        try:
            data = self.datosdis.protectedtype.text
        except AttributeError:
            pass
        return data

    @property
    def essentialtype(self):
        data = False
        try:
            data = self.datosdis.essentialtype.text
        except AttributeError:
            pass
        return data

    @property
    def fecactdist(self):
        data = False
        try:
            data = self.datosdis.fecactdist.text
        except AttributeError:
            pass
        return data

    @property
    def listaproductos(self):
        data = []
        obj = get_rec_attr(self.obj, self._header, False)
        if (hasattr(obj, 'listaproductos') and
                hasattr(obj.listaproductos, 'producto')):
            for i in self.datosdis.listaproductos:
                data.append(Producto(i))
        return data

class HistoricoConsumo(object):
    def __init__(self, data):
        self.historicoConsumo = data

    @property
    def fecinicioperiodo(self):
        data = False
        try:
            data = self.historicoConsumo.fecinicioperiodo.text
        except AttributeError:
            pass
        return data

    @property
    def fecfinperiodo(self):
        data = False
        try:
            data = self.historicoConsumo.fecfinperiodo.text
        except AttributeError:
            pass
        return data

    @property
    def consumoperiodo(self):
        data = False
        try:
            data = self.historicoConsumo.consumoperiodo.text
        except AttributeError:
            pass
        return data

    @property
    def caudalminperiodo(self):
        data = False
        try:
            data = self.historicoConsumo.caudalminperiodo.text
        except AttributeError:
            pass
        return data

    @property
    def caudalmedperiodo(self):
        data = False
        try:
            data = self.historicoConsumo.caudalmedperiodo.text
        except AttributeError:
            pass
        return data

    @property
    def caudalmaxperiodo(self):
        data = False
        try:
            data = self.historicoConsumo.caudalmaxperiodo.text
        except AttributeError:
            pass
        return data


class Producto(object):
    def __init__(self, data):
        self.prod = data

    @property
    def codigoproducto(self):
        data = False
        try:
            data = self.prod.codigoproducto.text
        except AttributeError:
            pass
        return data

    @property
    def tipoproducto(self):
        data = False
        try:
            data = self.prod.tipoproducto.text
        except AttributeError:
            pass
        return data

    @property
    def tarifaproducto(self):
        data = False
        try:
            data = self.prod.tarifaproducto.text
        except AttributeError:
            pass
        return data

    @property
    def qdproducto(self):
        data = False
        try:
            data = self.prod.qdproducto.text
        except AttributeError:
            pass
        return data

    @property
    def qaproducto(self):
        data = False
        try:
            data = self.prod.qaproducto.text
        except AttributeError:
            pass
        return data

    @property
    def fechainicioproducto(self):
        data = False
        try:
            data = self.prod.fechainicioproducto.text
        except AttributeError:
            pass
        return data

    @property
    def horainicioproducto(self):
        data = False
        try:
            data = self.prod.horainicioproducto.text
        except AttributeError:
            pass
        return data

    @property
    def fechafinproducto(self):
        data = False
        try:
            data = self.prod.fechafinproducto.text
        except AttributeError:
            pass
        return data


class DatosCom(object):
    def __init__(self, data):
        self.datoscom = data

    @property
    def nombre(self):
        data = False
        try:
            data = self.datoscom.nombre.text
        except AttributeError:
            pass
        return data

    @property
    def apellido1(self):
        data = False
        try:
            data = self.datoscom.apellido1.text
        except AttributeError:
            pass
        return data

    @property
    def apellido2(self):
        data = False
        try:
            data = self.datoscom.apellido2.text
        except AttributeError:
            pass
        return data

    @property
    def codprovincia(self):
        data = False
        try:
            data = self.datoscom.codprovincia.text
        except AttributeError:
            pass
        return data

    @property
    def descprovincia(self):
        data = False
        try:
            data = self.datoscom.descprovincia.text
        except AttributeError:
            pass
        return data

    @property
    def codpostal(self):
        data = False
        try:
            data = self.datoscom.codpostal.text
        except AttributeError:
            pass
        return data

    @property
    def codmunicipio(self):
        data = False
        try:
            data = self.datoscom.codmunicipio.text
        except AttributeError:
            pass
        return data

    @property
    def descmunicipio(self):
        data = False
        try:
            data = self.datoscom.descmunicipio.text
        except AttributeError:
            pass
        return data

    @property
    def tipovia(self):
        data = False
        try:
            data = self.datoscom.tipovia.text
        except AttributeError:
            pass
        return data

    @property
    def via(self):
        data = False
        try:
            data = self.datoscom.via.text
        except AttributeError:
            pass
        return data

    @property
    def numfinca(self):
        data = False
        try:
            data = self.datoscom.numfinca.text
        except AttributeError:
            pass
        return data

    @property
    def portal(self):
        data = False
        try:
            data = self.datoscom.portal.text
        except AttributeError:
            pass
        return data

    @property
    def escalera(self):
        data = False
        try:
            data = self.datoscom.escalera.text
        except AttributeError:
            pass
        return data

    @property
    def piso(self):
        data = False
        try:
            data = self.datoscom.piso.text
        except AttributeError:
            pass
        return data

    @property
    def puerta(self):
        data = False
        try:
            data = self.datoscom.puerta.text
        except AttributeError:
            pass
        return data

    @property
    def tipopersona(self):
        data = False
        try:
            data = self.datoscom.tipopersona.text
        except AttributeError:
            pass
        return data

    @property
    def viviendahabitual(self):
        data = False
        try:
            data = self.datoscom.viviendahabitual.text
        except AttributeError:
            pass
        return data

    @property
    def impagos(self):
        data = False
        try:
            data = self.datoscom.impagos.text
        except AttributeError:
            pass
        return data

    @property
    def fecimpagos(self):
        data = False
        try:
            data = self.datoscom.fecimpagos.text
        except AttributeError:
            pass
        return data

    @property
    def catimpagos(self):
        data = False
        try:
            data = self.datoscom.catimpagos.text
        except AttributeError:
            pass
        return data

    @property
    def usuimpagos(self):
        data = False
        try:
            data = self.datoscom.usuimpagos.text
        except AttributeError:
            pass
        return data

    @property
    def prohibpublicdatcli(self):
        data = False
        try:
            data = self.datoscom.prohibpublicdatcli.text
        except AttributeError:
            pass
        return data

    @property
    def fecactprohibpublic(self):
        data = False
        try:
            data = self.datoscom.fecactprohibpublic.text
        except AttributeError:
            pass
        return data

    @property
    def catactprohibpublic(self):
        data = False
        try:
            data = self.datoscom.catactprohibpublic.text
        except AttributeError:
            pass
        return data

    @property
    def usuactprohibpublic(self):
        data = False
        try:
            data = self.datoscom.usuactprohibpublic.text
        except AttributeError:
            pass
        return data



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from .M1 import M1
from .C1 import DatosActivacion
from gestionatr.utils import get_rec_attr


class M2(M1):
    """Classe que implementa M2."""

    # Datos paso 05
    @property
    def datos_activacion(self):
        tree = '{0}.DatosActivacion'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return DatosActivacion(data)
        else:
            return False


class DatosActivacion(DatosActivacion):
    @property
    def motivo_activacion_unidireccional(self):
        data = []
        try:
            for datos in self.datos_activacion.MotivoActivacionUnidireccional:
                data.append(MotivoActivacionUnidireccional(datos))
        except AttributeError:
            pass
        return data

class MotivoActivacionUnidireccional(object):

    def __init__(self, data):
        self.motivo_activacion_unidireccional = data

    @property
    def motivo(self):
        data = False
        try:
            data = self.motivo_activacion_unidireccional.Motivo.text
        except AttributeError:
            pass
        return data



# -*- coding: utf-8 -*-

from libcomxml.core import XmlModel, XmlField
from gestionatr.output.messages.base_gas import Cabecera


class MensajeA529(XmlModel):
    _sort_order = ('mensaje', 'cabecera', 'a529')

    def __init__(self):
        self.doc_root = None
        self.mensaje = XmlField(
            'sctdapplication', attributes={'xmlns': 'http://localhost/sctd/A529'}
        )
        self.cabecera = Cabecera()
        self.a529 = A529()
        super(MensajeA529, self).__init__('sctdapplication', 'mensaje')


class A529(XmlModel):
    _sort_order = (
        'a529', 'fechacreacion', 'horacreacion', 'cups', 'historicoconsumo', 'validacioncliente'
    )

    def __init__(self):
        self.a529 = XmlField('a529')
        self.fechacreacion = XmlField('fechacreacion')
        self.horacreacion = XmlField('horacreacion')
        self.cups = XmlField('cups')
        self.historicoconsumo = XmlField('historicoconsumo')
        self.validacioncliente = ValidacionClienteA529()

        super(A529, self).__init__('a529', 'a529')


class ValidacionClienteA529(XmlModel):
    _sort_order = (
        'validacioncliente', 'tipodocumento', 'numdocumento'
    )

    def __init__(self):
        self.validacioncliente = XmlField('validacioncliente')
        self.tipodocumento = XmlField('tipodocumento')
        self.numdocumento = XmlField('numdocumento')

        super(ValidacionClienteA529, self).__init__('validacioncliente', 'validacioncliente')


GAS_ENVELOPE_TEMPLATE_CHATGPT = """
<soapenv:Envelope 
xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/" 
xmlns:wsr="http://localhost/sctd/wsrps" 
xmlns:a529="http://localhost/sctd/A529">
   <soapenv:Header/>
   <soapenv:Body>
      <wsr:consultaCups>
         <consultaCups>
{xml_str}
         </consultaCups>
      </wsr:consultaCups>
   </soapenv:Body>
</soapenv:Envelope>
"""


ENVELOP_GAS_BY_DISTR = {
    'altres': {
        'template': GAS_ENVELOPE_TEMPLATE_CHATGPT,
        'extra_headers': {
            "soapAction": ""
        },
    },
}



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from gestionatr.input.messages.C1 import Rechazo, Autoconsumo
from gestionatr.input.messages.C2 import Cliente, Direccion
from .message import Message
from .Deadlines import ProcessDeadline
from gestionatr.utils import get_rec_attr


class P0(Message, ProcessDeadline):
    """Clase que implementa P0."""

    # Datos paso 01
    @property
    def tipo_identificador(self):
        tree = '{0}.TipoIdentificador'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def identificador(self):
        tree = '{0}.Identificador'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    # Datos paso 02 aceptacion
    @property
    def resultado_validacion_cliente(self):
        tree = '{0}.ResultadoValidacionCliente'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def en_vigor(self):
        tree = '{0}.EnVigor'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def estado_contratable(self):
        tree = '{0}.EstadoContratable'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return EstadoContratable(data)
        else:
            return False

    @property
    def existe_solicitud_en_curso(self):
        tree = '{0}.ExisteSolicitudEnCurso'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def tipo_solicitud_en_curso(self):
        tree = '{0}.TipoSolicitudEnCurso'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def contrato(self):
        tree = '{0}.Contrato'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return Contrato(data)
        else:
            return False

    @property
    def fecha_ultimo_movimiento_tipo_autocons(self):
        tree = '{0}.FechaUltimoMovimientoTipoAutocons'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def ind_bono_social(self):
        tree = '{0}.IndBonoSocial'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def ind_esencial(self):
        tree = '{0}.IndEsencial'.format(self._header)
        data = get_rec_attr(self.obj, tree, '')
        # pot ser que IndEsencial tingui valor '00' indicant que no te. Llavors get_rec_attr el retorna com '0' que
        # s'interpreta com False pero despres fent data.text retorna '00' per tant es posa default com a ''
        if data != '':
            return data.text
        else:
            return False

    @property
    def fecha_ultimo_movimiento_ind_esencial(self):
        tree = '{0}.FechaUltimoMovimientoIndEsencial'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def vivienda_habitual(self):
        tree = '{0}.ViviendaHabitual'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def cnae(self):
        tree = '{0}.CNAE'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def condiciones_contractuales(self):
        tree = '{0}.CondicionesContractuales'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return CondicionesContractuales(data)
        else:
            return False

    @property
    def modo_facturacion_potencia(self):
        tree = '{0}.ModoFacturacionPotencia'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def no_interrumpible(self):
        tree = '{0}.NoInterrumpible'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def potencia_no_interrumpible(self):
        tree = '{0}.PotenciaNoInterrumpible'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def vas_trafo(self):
        tree = '{0}.VAsTrafo'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def periodicidad_facturacion(self):
        tree = '{0}.PeriodicidadFacturacion'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def tipo_de_telegestion(self):
        tree = '{0}.TipodeTelegestion'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def icp_activado_telegestion(self):
        tree = '{0}.ICPActivadoTelegestion'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def peaje_directo(self):
        tree = '{0}.PeajeDirecto'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def deposito_garantia(self):
        tree = '{0}.DepositoGarantia'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def potencia_maxima_autorizada(self):
        tree = '{0}.PotenciaMaxAutorizada'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def tension_del_suministro(self):
        tree = '{0}.TensionDelSuministro'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def derechos_reconocidos(self):
        tree = '{0}.DerechosReconocidos'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return DerechosReconocidos(data)
        else:
            return False

    @property
    def caracteristicas_pm(self):
        tree = '{0}.CaracteristicasPM'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return CaracteristicasPM(data)
        else:
            return False

    @property
    def historia(self):
        tree = '{0}.Historia'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return Historia(data)
        else:
            return False

    @property
    def cliente(self):
        tree = '{0}.Cliente'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return Cliente(data)
        else:
            return False

    @property
    def equipo(self):
        data = []
        tree = get_rec_attr(self.obj, self._header, False)
        if hasattr(tree, 'Equipo'):
            for datos in tree.Equipo:
                data.append(Equipo(datos))
            return data
        else:
            return False

    @property
    def doc_tecnica(self):
        tree = '{0}.DocTecnica'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return DocTecnica(data)
        else:
            return False

    @property
    def puntos_de_medida(self):
        data = []
        obj = get_rec_attr(self.obj, self._header, False)
        if (hasattr(obj, 'PuntosDeMedida') and
                hasattr(obj.PuntosDeMedida, 'PuntoDeMedida')):
            for d in obj.PuntosDeMedida.PuntoDeMedida:
                data.append(PuntoDeMedida(d))
        return data

    @property
    def expediente_anomalia_fraude(self):
        tree = '{0}.ExpedienteAnomaliaFraude'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return ExpedienteAnomaliaFraude(data)
        else:
            return False

    @property
    def expediente_acometida(self):
        tree = '{0}.ExpedienteAcometida'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return ExpedienteAcometida(data)
        else:
            return False

    # Datos paso 02 rechazo
    @property
    def fecha_rechazo(self):
        tree = '{0}.FechaRechazo'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def rechazo(self):
        data = []
        tree = get_rec_attr(self.obj, self._header, False)
        if hasattr(tree, 'Rechazo'):
            for datos in tree.Rechazo:
                data.append(Rechazo(datos))
            return data
        else:
            return False


class Cliente(Cliente):

    @property
    def direccion_suministro(self):
        data = ''
        try:
            data = Direccion(self.cliente.DireccionSuministro)
        except AttributeError:
            pass
        return data


class EstadoContratable(object):

    def __init__(self, data):
        self.estado_contratable = data

    @property
    def contratable(self):
        data = ''
        try:
            data = self.estado_contratable.Contratable.text
        except AttributeError:
            pass
        return data

    @property
    def motivo(self):
        data = ''
        try:
            data = self.estado_contratable.Motivo.text
        except AttributeError:
            pass
        return data

    @property
    def potencia_max_sin_expediente(self):
        data = ''
        try:
            data = self.estado_contratable.PotenciaMaxSinExpediente.text
        except AttributeError:
            pass
        return data


class Contrato(object):

    def __init__(self, data):
        self.contrato = data

    @property
    def tipo_contrato_atr(self):
        data = ''
        try:
            data = self.contrato.TipoContratoATR.text
        except AttributeError:
            pass
        return data

    @property
    def fecha_finalizacion(self):
        data = ''
        try:
            data = self.contrato.FechaFinalizacion.text
        except AttributeError:
            pass
        return data

    @property
    def autoconsumo(self):
        data = ''
        try:
            data = Autoconsumo(self.contrato.Autoconsumo)
        except AttributeError:
            pass
        return data


class CondicionesContractuales(object):

    def __init__(self, data):
        self.condiciones_contractuales = data

    @property
    def tarifa_atr(self):
        data = ''
        try:
            data = self.condiciones_contractuales.TarifaATR.text
        except AttributeError:
            pass
        return data

    @property
    def potencias_contratadas(self):
        data = []
        obj = self.condiciones_contractuales
        if (hasattr(obj, 'PotenciasContratadas') and
                hasattr(obj.PotenciasContratadas, 'Potencia')):
            for d in obj.PotenciasContratadas.Potencia:
                data.append((int(d.get('Periodo')), int(d.text)))
        return data

    @property
    def modo_control_potencia(self):
        data = ''
        try:
            data = self.condiciones_contractuales.ModoControlPotencia.text
        except AttributeError:
            pass
        return data


class DerechosReconocidos(object):

    def __init__(self, data):
        self.derechos_reconocidos = data

    @property
    def derecho_acceso(self):
        data = ''
        try:
            data = self.derechos_reconocidos.DerechoAcceso.text
        except AttributeError:
            pass
        return data

    @property
    def derecho_extension(self):
        data = ''
        try:
            data = self.derechos_reconocidos.DerechosExtension.text
        except AttributeError:
            pass
        return data

    @property
    def fecha_limite_derechos_extension(self):
        data = ''
        try:
            data = self.derechos_reconocidos.FechaLimiteDerechosExtension.text
        except AttributeError:
            pass
        return data


class CaracteristicasPM(object):

    def __init__(self, data):
        self.caracteristicas_pm = data

    @property
    def tipo_pm(self):
        data = ''
        try:
            data = self.caracteristicas_pm.TipoPM.text
        except AttributeError:
            pass
        return data

    @property
    def tension_pm(self):
        data = ''
        try:
            data = self.caracteristicas_pm.TensionPM.text
        except AttributeError:
            pass
        return data


class Historia(object):

    def __init__(self, data):
        self.historia = data

    @property
    def fecha_ultimo_movimiento_contratacion(self):
        data = ''
        try:
            data = self.historia.FechaUltimoMovimientoContratacion.text
        except AttributeError:
            pass
        return data

    @property
    def fecha_cambio_comercializador(self):
        data = ''
        try:
            data = self.historia.FechaCambioComercializador.text
        except AttributeError:
            pass
        return data

    @property
    def fecha_ultima_lectura(self):
        data = ''
        try:
            data = self.historia.FechaUltimaLectura.text
        except AttributeError:
            pass
        return data

    @property
    def fecha_ultima_verificacion(self):
        data = ''
        try:
            data = self.historia.FechaUltimaVerificacion.text
        except AttributeError:
            pass
        return data

    @property
    def resultado_ultima_lectura(self):
        data = ''
        try:
            data = self.historia.ResultadoUltimaVerificacion.text
        except AttributeError:
            pass
        return data


class Equipo(object):

    def __init__(self, data):
        self.equipo = data

    @property
    def tipo_aparato(self):
        data = ''
        try:
            data = self.equipo.TipoAparato.text
        except AttributeError:
            pass
        return data

    @property
    def tipo_equipo(self):
        data = ''
        try:
            data = self.equipo.TipoEquipo.text
        except AttributeError:
            pass
        return data

    @property
    def tipo_propiedad(self):
        data = ''
        try:
            data = self.equipo.TipoPropiedad.text
        except AttributeError:
            pass
        return data

    @property
    def codigo_fases_equipo_medida(self):
        data = ''
        try:
            data = self.equipo.CodigoFasesEquipoMedida.text
        except AttributeError:
            pass
        return data

    @property
    def tipo_dh_edm(self):
        data = ''
        try:
            data = self.equipo.TipoDHEdM.text
        except AttributeError:
            pass
        return data

    @property
    def relacion_transformacion_intensidad(self):
        data = ''
        try:
            data = self.equipo.RelacionTransformacionIntensidad.text
        except AttributeError:
            pass
        return data


class DocTecnica(object):

    def __init__(self, data):
        self.doc_tecnica = data

    @property
    def cie_disponible(self):
        data = ''
        try:
            data = self.doc_tecnica.CIEDisponible.text
        except AttributeError:
            pass
        return data

    @property
    def datos_cie(self):
        data = ''
        try:
            data = DatosCie(self.doc_tecnica.DatosCie)
        except AttributeError:
            pass
        return data

    @property
    def datos_apm(self):
        data = ''
        try:
            data = DatosAPM(self.doc_tecnica.DatosAPM)
        except AttributeError:
            pass
        return data


class DatosCie(object):

    def __init__(self, data):
        self.datos_cie = data

    @property
    def potencia_inst_bt(self):
        data = ''
        try:
            data = self.datos_cie.PotenciaInstBT.text
        except AttributeError:
            pass
        return data

    @property
    def cie_papel(self):
        data = ''
        try:
            data = CIEPapel(self.datos_cie.CIEPapel)
        except AttributeError:
            pass
        return data

    @property
    def cie_electronico(self):
        data = ''
        try:
            data = CIEElectronico(self.datos_cie.CIEElectronico)
        except AttributeError:
            pass
        return data

    @property
    def validez_cie(self):
        data = ''
        try:
            data = self.datos_cie.ValidezCIE.text
        except AttributeError:
            pass
        return data


class CIEPapel(object):

    def __init__(self, data):
        self.cie_papel = data

    @property
    def codigo_cie(self):
        data = ''
        try:
            data = self.cie_papel.CodigoCie.text
        except AttributeError:
            pass
        return data

    @property
    def fecha_emision_cie(self):
        data = ''
        try:
            data = self.cie_papel.FechaEmisionCie.text
        except AttributeError:
            pass
        return data

    @property
    def fecha_caducidad_cie(self):
        data = ''
        try:
            data = self.cie_papel.FechaCaducidadCie.text
        except AttributeError:
            pass
        return data

    @property
    def tension_suministro_cie(self):
        data = ''
        try:
            data = self.cie_papel.TensionSuministroCIE.text
        except AttributeError:
            pass
        return data

    @property
    def tipo_suministro(self):
        data = ''
        try:
            data = self.cie_papel.TipoSuministro.text
        except AttributeError:
            pass
        return data


class CIEElectronico(object):

    def __init__(self, data):
        self.cie_electronico = data

    @property
    def codigo_cie(self):
        data = ''
        try:
            data = self.cie_electronico.CodigoCie.text
        except AttributeError:
            pass
        return data

    @property
    def sello_electronico(self):
        data = ''
        try:
            data = self.cie_electronico.SelloElectronico.text
        except AttributeError:
            pass
        return data


class DatosAPM(object):

    def __init__(self, data):
        self.datos_apm = data

    @property
    def codigo_apm(self):
        data = ''
        try:
            data = self.datos_apm.CodigoApm.text
        except AttributeError:
            pass
        return data

    @property
    def potencia_inst_at(self):
        data = ''
        try:
            data = self.datos_apm.PotenciaInstAT.text
        except AttributeError:
            pass
        return data

    @property
    def fecha_emision_apm(self):
        data = ''
        try:
            data = self.datos_apm.FechaEmisionApm.text
        except AttributeError:
            pass
        return data

    @property
    def fecha_caducidad_apm(self):
        data = ''
        try:
            data = self.datos_apm.FechaCaducidadApm.text
        except AttributeError:
            pass
        return data


class ExpedienteAnomaliaFraude(object):

    def __init__(self, data):
        self.expediente_anomalia_fraude = data

    @property
    def expediente_abierto(self):
        data = ''
        try:
            data = self.expediente_anomalia_fraude.ExpedienteAbierto.text
        except AttributeError:
            pass
        return data

    @property
    def codigo_motivo_expediente(self):
        data = ''
        try:
            data = self.expediente_anomalia_fraude.CdigoMotivoExpediente.text
        except AttributeError:
            pass
        return data


class ExpedienteAcometida(object):

    def __init__(self, data):
        self.expediente_acometida = data

    @property
    def expediente_abierto(self):
        data = ''
        try:
            data = self.expediente_acometida.ExpedienteAbierto.text
        except AttributeError:
            pass
        return data

    @property
    def codigo_motivo_expediente(self):
        data = ''
        try:
            data = self.expediente_acometida.CdigoMotivoExpediente.text
        except AttributeError:
            pass
        return data


class PuntoDeMedida(object):

    def __init__(self, data):
        self.punto_de_medida = data

    @property
    def direccion_enlace(self):
        data = ''
        try:
            data = self.punto_de_medida.DireccionEnlace.text
        except AttributeError:
            pass
        return data

    @property
    def telefono_telemedida(self):
        data = ''
        try:
            data = self.punto_de_medida.TelefonoTelemedida.text
        except AttributeError:
            pass
        return data

    @property
    def clave_acceso(self):
        data = ''
        try:
            data = self.punto_de_medida.ClaveAcceso.text
        except AttributeError:
            pass
        return data

# class MinimumFieldsChecker(object):
#
#     def __init__(self, p0):
#         self.p0 = p0
#
#     def check(self):
#         errors = []
#
#         for field in self.get_minimum_fields(pas=self.p0.pas):
#             valid = getattr(self, 'check_{0}'.format(field), None)
#             if not valid():
#                 errors.append(field)
#         return errors
#
#     def get_minimum_fields(self, pas='01'):
#         if pas == '01':
#             return [
#                 'moviment', 'cau', 'seccio_registre', 'collectiu', 'cups', 'tec_generador',
#                 'pot_installada_gen', 'tipus_installacio', 'ssaa', 'nom_titular', 'tipus_identificador',
#                 'identificador', 'telefon', 'pais', 'provincia', 'municipi', 'codi_postal', 'via_or_apartat_correus'
#             ]
#         elif pas == '02':
#             return ['cau']
#         else:
#             return False
#
#     def check_moviment(self):
#         return get_rec_attr(self.a1, "movimiento", False)
#
#     def check_cau(self):
#         return get_rec_attr(self.a1, "autoconsumo.cau", False)
#
#     def check_seccio_registre(self):
#         return get_rec_attr(self.a1, "autoconsumo.seccion_registro", False)
#
#     def check_collectiu(self):
#         return get_rec_attr(self.a1, "autoconsumo.colectivo", False)
#
#     def check_cups(self):
#         valid = True
#         for datos in self.a1.datos_suministro:
#             valid = valid and get_rec_attr(datos, "cups", False)
#         return valid
#
#     def check_tec_generador(self):
#         valid = True
#         for datos in self.a1.datos_inst_gen:
#             valid = valid and get_rec_attr(datos, "tec_generador", False)
#         return valid
#
#     def check_pot_installada_gen(self):
#         valid = True
#         for datos in self.a1.datos_inst_gen:
#             valid = valid and get_rec_attr(datos, "pot_instalada_gen", False)
#         return valid
#
#     def check_tipus_installacio(self):
#         valid = True
#         for datos in self.a1.datos_inst_gen:
#             valid = valid and get_rec_attr(datos, "tipo_instalacion", False)
#         return valid
#
#     def check_ssaa(self):
#         valid = True
#         for datos in self.a1.datos_inst_gen:
#             valid = valid and get_rec_attr(datos, "ssaa", False)
#         return valid
#
#     def check_nom_titular(self):
#         valid = True
#         if self.a1.autoconsumo.seccion_registro == '2':
#             for datos in self.a1.datos_inst_gen:
#                 nom = datos.titular_representante_gen.nombre
#                 check = get_rec_attr(nom, "nombre_de_pila", False) and \
#                         get_rec_attr(nom, "primer_apellido", False) or \
#                         get_rec_attr(nom, "razon_social", False)
#                 valid = valid and check
#         return valid
#
#     def check_tipus_identificador(self):
#         valid = True
#         if self.a1.autoconsumo.seccion_registro == '2':
#             for datos in self.a1.datos_inst_gen:
#                 valid = valid and get_rec_attr(datos.titular_representante_gen.id_titular, "tipo_identificador", False)
#         return valid
#
#     def check_identificador(self):
#         valid = True
#         if self.a1.autoconsumo.seccion_registro == '2':
#             for datos in self.a1.datos_inst_gen:
#                 valid = valid and get_rec_attr(datos.titular_representante_gen.id_titular, "identificador", False)
#         return valid
#
#     def check_telefon(self):
#         valid = True
#         if self.a1.autoconsumo.seccion_registro == '2':
#             for datos in self.a1.datos_inst_gen:
#                 telefon = get_rec_attr(datos.titular_representante_gen, "telefono", False)
#                 if not telefon:
#                     return False
#                 valid = valid and len(telefon) > 0
#         return valid
#
#     def check_pais(self):
#         valid = True
#         if self.a1.autoconsumo.seccion_registro == '2':
#             for datos in self.a1.datos_inst_gen:
#                 direccio = datos.titular_representante_gen.direccion
#                 valid = valid and get_rec_attr(direccio, "pais", False)
#         return valid
#
#     def check_provincia(self):
#         valid = True
#         if self.a1.autoconsumo.seccion_registro == '2':
#             for datos in self.a1.datos_inst_gen:
#                 direccio = datos.titular_representante_gen.direccion
#                 valid = valid and get_rec_attr(direccio, "provincia", False)
#         return valid
#
#     def check_municipi(self):
#         valid = True
#         if self.a1.autoconsumo.seccion_registro == '2':
#             for datos in self.a1.datos_inst_gen:
#                 direccio = datos.titular_representante_gen.direccion
#                 valid = valid and get_rec_attr(direccio, "municipio", False)
#         return valid
#
#     def check_codi_postal(self):
#         valid = True
#         if self.a1.autoconsumo.seccion_registro == '2':
#             for datos in self.a1.datos_inst_gen:
#                 direccio = datos.titular_representante_gen.direccion
#                 valid = valid and get_rec_attr(direccio, "cod_postal", False)
#         return valid
#
#     def check_via_or_apartat_correus(self):
#         valid = True
#         if self.a1.autoconsumo.seccion_registro == '2':
#             for datos in self.a1.datos_inst_gen:
#                 direccio = datos.titular_representante_gen.direccion
#                 has_apartado_correos = get_rec_attr(direccio, "apartado_de_correos", False)
#                 has_via = get_rec_attr(direccio, "tipo_via", False) and \
#                           get_rec_attr(direccio, "calle", False) and \
#                           get_rec_attr(direccio, "numero_finca", False)
#                 valid = valid and (has_apartado_correos or has_via)
#         return valid



# -*- coding: utf-8 -*-
from gestionatr.output.messages.sw_c2 import *
from gestionatr.output.messages.sw_c1 import Medida, Contrato

# Paso 01

class MensajeSolicitudDesistimiento(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'solicitud_desistimiento')

    def __init__(self):
        self.mensaje = XmlField('MensajeSolicitudDesistimiento',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.solicitud_desistimiento = SolicitudDesistimiento()
        super(MensajeSolicitudDesistimiento, self) \
            .__init__('MensajeSolicitudDesistimiento', 'mensaje')


class SolicitudDesistimiento(XmlModel):

    _sort_order = ('solicitud_desistimiento', 'codigo_de_solicitud_ref', 'tipo_de_solicitud', 'ind_esencial',
                   'fecha_ultimo_movimiento_ind_esencial', 'id_cliente', 'registros_documento')

    def __init__(self):
        self.solicitud_desistimiento = XmlField('SolicitudDesistimiento')
        self.codigo_de_solicitud_ref = XmlField('CodigoDeSolicitudRef')
        self.tipo_de_solicitud = XmlField('TipoDeSolicitud')
        self.ind_esencial = XmlField('IndEsencial')
        self.fecha_ultimo_movimiento_ind_esencial = XmlField('FechaUltimoMovimientoIndEsencial')
        self.id_cliente = IdCliente()
        self.registros_documento = RegistrosDocumento()
        super(SolicitudDesistimiento, self).__init__('SolicitudDesistimiento', 'solicitud_desistimiento')


# Paso 02

class MensajeAceptacionDesistimiento(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'aceptacion_desistimiento')

    def __init__(self):
        self.mensaje = XmlField('MensajeAceptacionDesistimiento',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.aceptacion_desistimiento = AceptacionDesistimiento()
        super(MensajeAceptacionDesistimiento, self).__init__('MensajeAceptacionDesistimiento', 'mensaje')


class AceptacionDesistimiento(XmlModel):

    _sort_order = ('aceptacion_desistimiento', 'fecha_aceptacion',
                   'ind_anulable', 'actuacion_campo', 'fecha_activacion_prevista')

    def __init__(self):
        self.aceptacion_desistimiento = XmlField('AceptacionDesistimiento')
        self.fecha_aceptacion = XmlField('FechaAceptacion')
        self.ind_anulable = XmlField('IndAnulable')
        self.actuacion_campo = XmlField('ActuacionCampo')
        self.fecha_activacion_prevista = XmlField('FechaActivacionPrevista')
        super(AceptacionDesistimiento, self).__init__('AceptacionDesistimiento', 'aceptacion_desistimiento')


# Paso 05

class MensajeActivacionDesistimiento(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'activacion_desistimiento')

    def __init__(self):
        self.mensaje = XmlField('MensajeActivacionDesistimiento',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.activacion_desistimiento = ActivacionDesistimiento()
        super(MensajeActivacionDesistimiento, self).__init__('MensajeActivacionDesistimiento', 'mensaje')


class ActivacionDesistimiento(XmlModel):

    _sort_order = ('activacion_desistimiento', 'datos_notificacion', 'contrato', 'puntos_de_medida')

    def __init__(self):
        self.activacion_desistimiento = XmlField('ActivacionDesistimiento')
        self.datos_notificacion = DatosNotificacion()
        self.contrato = Contrato()
        self.puntos_de_medida = PuntosDeMedida()
        super(ActivacionDesistimiento, self).__init__('ActivacionDesistimiento', 'activacion_desistimiento')


class DatosNotificacion(DatosNotificacion):

    _sort_order = ('datos_notificacion', 'fecha_activacion', 'resultado_activacion', 'ind_anulable')

    def __init__(self):
        super(DatosNotificacion, self).__init__()
        self.resultado_activacion = XmlField('ResultadoActivacion')
        self.ind_anulable = XmlField('IndAnulable')


# Paso 06

class MensajeNotificacionActivacionPorDesistimiento(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'notificacion_activacion_desistimiento')

    def __init__(self):
        self.mensaje = XmlField('MensajeNotificacionActivacionPorDesistimiento',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.notificacion_activacion_desistimiento = NotificacionActivacionPorDesistimiento()
        super(MensajeNotificacionActivacionPorDesistimiento, self)\
            .__init__('MensajeNotificacionActivacionPorDesistimiento', 'mensaje')


class NotificacionActivacionPorDesistimiento(XmlModel):

    _sort_order = ('notificacion_activacion_desistimiento', 'datos_activacion', 'contrato', 'puntos_de_medida',
                   'registros_documento')

    def __init__(self):
        self.notificacion_activacion_desistimiento = XmlField('NotificacionActivacionPorDesistimiento')
        self.datos_activacion = DatosActivacion()
        self.contrato = Contrato()
        self.puntos_de_medida = PuntosDeMedida()
        self.registros_documento = RegistrosDocumento()
        super(NotificacionActivacionPorDesistimiento, self).__init__('NotificacionActivacionPorDesistimiento',
                                                                     'notificacion_activacion_desistimiento')


class DatosActivacion(DatosActivacion):

    _sort_order = ('datos_activacion', 'fecha', 'en_servicio', 'ind_anulable', 'ind_esencial',
                   'fecha_ultimo_movimiento_ind_esencial')

    def __init__(self):
        super(DatosActivacion, self).__init__()
        self.en_servicio = XmlField('EnServicio')
        self.ind_anulable = XmlField('IndAnulable')


class Medida(Medida):

    _sort_order = ('medida', 'tipo_dhedm', 'periodo', 'magnitud_medida', 'procedencia', 'ultima_lectura_firme',
                   'fecha_lectura_firme', 'anomalia', 'comentarios')

    def __init__(self):
        super(Medida, self).__init__()


class Contrato(Contrato):

    _sort_order = ('contrato', 'id_contrato', 'autoconsumo', 'tipo_contrato_atr', 'cups_principal',
                   'condiciones_contractuales')

    def __init__(self):
        super(Contrato, self).__init__()
        self.cups_principal = XmlField('CUPSPrincipal')

# Paso 12

class MensajeRechazoDesistimiento(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'rechazo_desistimiento')

    def __init__(self):
        self.mensaje = XmlField('MensajeRechazoDesistimiento',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.rechazo_desistimiento = RechazoDesistimiento()
        super(MensajeRechazoDesistimiento, self).__init__('MensajeRechazoDesistimiento', 'mensaje')


class RechazoDesistimiento(XmlModel):

    _sort_order = ('rechazo_desistimiento', 'fecha_rechazo')

    def __init__(self):
        self.rechazo_desistimiento = XmlField('RechazoDesistimiento')
        self.fecha_rechazo = XmlField('FechaRechazo')
        super(RechazoDesistimiento, self).__init__('RechazoDesistimiento', 'rechazo_desistimiento')






# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from .A1_38 import *


class A1_49(A1_38):

    # Pas a2
    @property
    def indanulable(self):
        tree = '{0}.indanulable'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def indactcampo(self):
        tree = '{0}.indactcampo'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    # Pas a3
    @property
    def resactivacion(self):
        tree = '{0}.resactivacion'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def enservicio(self):
        tree = '{0}.enservicio'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from .A1_44 import *


class A1_03(A1_44):

    steps = []

    @property
    def annulmentreason(self):
        tree = '{0}.annulmentreason'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from libcomxml.core import XmlModel, XmlField
from gestionatr.output.messages.base import Cabecera
from gestionatr.output.messages.sw_f1 import PeriodoCCH, Periodo, EnergiaActiva, Expediente, InformacionAlConsumidor, Autoconsumo


class MensajeSaldoLecturasFacturacion(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'datos', 'energia_activa', 'autoconsumo', 'medidas', 'informacion_consumidor')

    def __init__(self):
        self.mensaje = XmlField('MensajeSaldoLecturasFacturacion',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.datos = Datos()
        self.energia_activa = EnergiaActiva()
        self.autoconsumo = Autoconsumo()
        self.medidas = Medidas()
        self.informacion_consumidor = InformacionAlConsumidor()
        super(MensajeSaldoLecturasFacturacion, self).__init__('MensajeSaldoLecturasFacturacion', 'mensaje')


class Cabecera(Cabecera):

    _sort_order = ('cabecera', 'codigo_ree_empresa_emisora', 'codigo_ree_empresa_destino', 'codigo_del_proceso',
                   'codigo_del_paso', 'codigo_de_solicitud', 'secuencial_de_solicitud', 'fecha', 'cups',
                   'codigo_fiscal_factura', 'tipo_factura', 'motivo_facturacion', 'codigo_factura_rectificada_anulada',
                   'expediente')

    def __init__(self):
        super(Cabecera, self).__init__()
        self.codigo_fiscal_factura = XmlField('CodigoFiscalFactura')
        self.tipo_factura = XmlField('TipoFactura')
        self.motivo_facturacion = XmlField('MotivoFacturacion')
        self.codigo_factura_rectificada_anulada = XmlField('CodigoFacturaRectificadaAnulada')
        self.expediente = Expediente()


class Datos(XmlModel):

    _sort_order = ('datos', 'tipo_autoconsumo', 'tipo_subseccion', 'datos_cau', 'tipo_cups',
                   'marca_medida_con_perdidas', 'vas_trafo', 'porcentaje_perdidas', 'indicativo_curva_carga',
                   'periodo_cch', 'periodo', 'tipo_pm')

    def __init__(self):
        self.datos = XmlField('Datos')
        self.tipo_autoconsumo = XmlField('TipoAutoconsumo')
        self.tipo_subseccion = XmlField('TipoSubseccion')
        self.tipo_cups = XmlField('TipoCUPS')
        self.marca_medida_con_perdidas = XmlField('MarcaMedidaConPerdidas')
        self.vas_trafo = XmlField('VAsTrafo')
        self.porcentaje_perdidas = XmlField('PorcentajePerdidas')
        self.indicativo_curva_carga = XmlField('IndicativoCurvaCarga')
        self.periodo_cch = PeriodoCCH()
        self.periodo = Periodo()
        self.tipo_pm = XmlField('TipoPM')
        super(Datos, self).__init__('Datos', 'datos')


class Medidas(XmlModel):

    _sort_order = ('medidas', 'cod_pm', 'modelo_aparato_list')

    def __init__(self):
        self.medidas = XmlField('Medidas')
        self.cod_pm = XmlField('CodPM')
        self.modelo_aparato_list = []
        super(Medidas, self).__init__('Medidas', 'medidas')


class ModeloAparato(XmlModel):

    _sort_order = ('modelo_aparato', 'tipo_aparato', 'marca_aparato', 'numero_serie', 'tipo_dhedm', 'integrador_list')

    def __init__(self):
        self.modelo_aparato = XmlField('ModeloAparato')
        self.tipo_aparato = XmlField('TipoAparato')
        self.marca_aparato = XmlField('MarcaAparato')
        self.numero_serie = XmlField('NumeroSerie')
        self.tipo_dhedm = XmlField('TipoDHEdM')
        self.integrador_list = []
        super(ModeloAparato, self).__init__('ModeloAparato', 'modelo_aparato')


class Integrador(XmlModel):

    _sort_order = ('integrador', 'magnitud', 'codigo_periodo', 'constante_multiplicadora', 'numero_ruedas_enteras', 'numero_ruedas_decimales', 'consumo_calculado', 'lectura_desde', 'lectura_hasta', 'ajuste', 'anomalia', 'fecha_hora_maximetro')

    def __init__(self):
        self.integrador = XmlField('Integrador')
        self.magnitud = XmlField('Magnitud')
        self.codigo_periodo = XmlField('CodigoPeriodo')
        self.constante_multiplicadora = XmlField('ConstanteMultiplicadora')
        self.numero_ruedas_enteras = XmlField('NumeroRuedasEnteras')
        self.numero_ruedas_decimales = XmlField('NumeroRuedasDecimales')
        self.consumo_calculado = XmlField('ConsumoCalculado')
        self.lectura_desde = LecturaDesde()
        self.lectura_hasta = LecturaHasta()
        self.ajuste = Ajuste()
        self.anomalia = Anomalia()
        self.fecha_hora_maximetro = XmlField('FechaHoraMaximetro')
        super(Integrador, self).__init__('Integrador', 'integrador')


class LecturaDesde(XmlModel):

    _sort_order = ('lectura_desde', 'fecha', 'procedencia', 'lectura')

    def __init__(self):
        self.lectura_desde = XmlField('LecturaDesde')
        self.fecha = XmlField('Fecha')
        self.procedencia = XmlField('Procedencia')
        self.lectura = XmlField('Lectura')
        super(LecturaDesde, self).__init__('LecturaDesde', 'lectura_desde')


class LecturaHasta(XmlModel):

    _sort_order = ('lectura_hasta', 'fecha', 'procedencia', 'lectura')

    def __init__(self):
        self.lectura_hasta = XmlField('LecturaHasta')
        self.fecha = XmlField('Fecha')
        self.procedencia = XmlField('Procedencia')
        self.lectura = XmlField('Lectura')
        super(LecturaHasta, self).__init__('LecturaHasta', 'lectura_hasta')


class Ajuste(XmlModel):

    _sort_order = ('ajuste', 'codigo_motivo_ajuste', 'ajuste_por_integrador', 'comentarios')

    def __init__(self):
        self.ajuste = XmlField('Ajuste')
        self.codigo_motivo_ajuste = XmlField('CodigoMotivoAjuste')
        self.ajuste_por_integrador = XmlField('AjustePorIntegrador')
        self.comentarios = XmlField('Comentarios')
        super(Ajuste, self).__init__('Ajuste', 'ajuste')


class Anomalia(XmlModel):

    _sort_order = ('anomalia', 'tipo_anomalia', 'comentarios')

    def __init__(self):
        self.anomalia = XmlField('Anomalia')
        self.tipo_anomalia = XmlField('TipoAnomalia')
        self.comentarios = XmlField('Comentarios')
        super(Anomalia, self).__init__('Anomalia', 'anomalia')



# -*- coding: utf-8 -*-
from gestionatr.output.messages.sw_c2 import *
from gestionatr.output.messages.sw_c1 import Medida, Contrato
from gestionatr.output.messages.sw_t1 import DireccionPS

# Paso 01

class MensajeSolicitudReposicion(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'solicitud_reposicion')

    def __init__(self):
        self.mensaje = XmlField('MensajeSolicitudReposicion',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.solicitud_reposicion = SolicitudReposicion()
        super(MensajeSolicitudReposicion, self).__init__('MensajeSolicitudReposicion', 'mensaje')


class SolicitudReposicion(XmlModel):

    _sort_order = ('solicitud_reposicion', 'codigo_de_solicitud_ref',
                   'tipo_de_reposicion', 'id_cliente', 'registros_documento', 'comentarios')

    def __init__(self):
        self.solicitud_reposicion = XmlField('SolicitudReposicion')
        self.codigo_de_solicitud_ref = XmlField('CodigoDeSolicitudRef')
        self.tipo_de_reposicion = XmlField('TipoDeReposicion')
        self.id_cliente = IdCliente()
        self.registros_documento = RegistrosDocumento()
        self.comentarios = XmlField('Comentarios')
        super(SolicitudReposicion, self).__init__('SolicitudReposicion', 'solicitud_reposicion')


# Paso 02

class MensajeAceptacionReposicion(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'aceptacion_reposicion')

    def __init__(self):
        self.mensaje = XmlField('MensajeAceptacionReposicion',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.aceptacion_reposicion = AceptacionReposicion()
        super(MensajeAceptacionReposicion, self).__init__('MensajeAceptacionReposicion', 'mensaje')


class AceptacionReposicion(XmlModel):

    _sort_order = ('aceptacion_reposicion', 'fecha_aceptacion',
                   'actuacion_campo', 'fecha_activacion_prevista')

    def __init__(self):
        self.aceptacion_reposicion = XmlField('AceptacionReposicion')
        self.fecha_aceptacion = XmlField('FechaAceptacion')
        self.actuacion_campo = XmlField('ActuacionCampo')
        self.fecha_activacion_prevista = XmlField('FechaActivacionPrevista')
        super(AceptacionReposicion, self).__init__('AceptacionReposicion', 'aceptacion_reposicion')


# Paso 05

class MensajeActivacionReposicion(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'activacion_reposicion')

    def __init__(self):
        self.mensaje = XmlField('MensajeActivacionReposicion',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.activacion_reposicion = ActivacionReposicion()
        super(MensajeActivacionReposicion, self).__init__('MensajeActivacionReposicion', 'mensaje')


class ActivacionReposicion(XmlModel):

    _sort_order = ('activacion_reposicion', 'datos_notificacion', 'contrato', 'puntos_de_medida',
                   'id_cliente', 'registros_documento', 'comentarios')

    def __init__(self):
        self.activacion_reposicion = XmlField('ActivacionReposicion')
        self.datos_notificacion = DatosNotificacion()
        self.contrato = Contrato()
        self.puntos_de_medida = PuntosDeMedida()
        self.id_cliente = IdCliente()
        self.registros_documento = RegistrosDocumento()
        self.comentarios = XmlField('Comentarios')
        super(ActivacionReposicion, self).__init__('ActivacionReposicion', 'activacion_reposicion')


class DatosNotificacion(XmlModel):

    _sort_order = ('datos_notificacion', 'fecha_activacion', 'resultado_activacion', 'codigo_sol_corte',
                   'ind_esencial', 'fecha_ultimo_movimiento_ind_esencial')

    def __init__(self):
        self.datos_notificacion = XmlField('DatosNotificacion')
        self.fecha_activacion = XmlField('FechaActivacion')
        self.resultado_activacion = XmlField('ResultadoActivacion')
        self.codigo_sol_corte = XmlField('CodigoSolCorte')
        self.ind_esencial = XmlField('IndEsencial')
        self.fecha_ultimo_movimiento_ind_esencial = XmlField('FechaUltimoMovimientoIndEsencial')
        super(DatosNotificacion, self).__init__('DatosNotificacion', 'datos_notificacion')


# Paso 06
class MensajeNotificacionActivacionPorReposicion(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'notificacion_activacion_reposicion')

    def __init__(self):
        self.mensaje = XmlField('MensajeNotificacionActivacionPorReposicion',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.notificacion_activacion_reposicion = NotificacionActivacionPorReposicion()
        super(MensajeNotificacionActivacionPorReposicion, self)\
            .__init__('MensajeNotificacionActivacionPorReposicion', 'mensaje')


class NotificacionActivacionPorReposicion(XmlModel):

    _sort_order = ('notificacion_activacion_reposicion', 'datos_activacion', 'contrato', 'puntos_de_medida')

    def __init__(self):
        self.notificacion_activacion_reposicion = XmlField('NotificacionActivacionPorReposicion')
        self.datos_activacion = DatosActivacion()
        self.contrato = Contrato()
        self.puntos_de_medida = PuntosDeMedida()
        super(NotificacionActivacionPorReposicion, self).__init__('NotificacionActivacionPorReposicion',
                                                                     'notificacion_activacion_reposicion')


class DatosActivacion(XmlModel):

    _sort_order = ('datos_activacion', 'fecha', 'resultado_activacion', 'en_servicio',)

    def __init__(self):
        self.datos_activacion = XmlField('DatosActivacion')
        self.fecha = XmlField('Fecha')
        self.resultado_activacion = XmlField('ResultadoActivacion')
        self.en_servicio = XmlField('EnServicio')
        super(DatosActivacion, self).__init__('DatosActivacion', 'datos_activacion')


class Medida(Medida):

    _sort_order = ('medida', 'tipo_dhedm', 'periodo', 'magnitud_medida', 'procedencia', 'ultima_lectura_firme',
                   'fecha_lectura_firme', 'anomalia', 'comentarios')

    def __init__(self):
        super(Medida, self).__init__()


class Contrato(Contrato):

    _sort_order = ('contrato', 'id_contrato', 'autoconsumo', 'tipo_contrato_atr', 'cups_principal',
                   'condiciones_contractuales')

    def __init__(self):
        super(Contrato, self).__init__()
        self.cups_principal = XmlField('CUPSPrincipal')

# Paso 12

class MensajeRechazoReposicion(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'rechazo_reposicion')

    def __init__(self):
        self.mensaje = XmlField('MensajeRechazoReposicion',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.rechazo_reposicion = RechazoReposicion()
        super(MensajeRechazoReposicion, self).__init__('MensajeRechazoReposicion', 'mensaje')


class RechazoReposicion(XmlModel):

    _sort_order = ('rechazo_reposicion', 'fecha_rechazo')

    def __init__(self):
        self.rechazo_reposicion = XmlField('RechazoReposicion')
        self.fecha_rechazo = XmlField('FechaRechazo')
        super(RechazoReposicion, self).__init__('RechazoReposicion', 'rechazo_reposicion')


# paso 14
class MensajeConsultaSolicitudReposicion(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'solicitud_reposicion', 'direccion_ps', 'registros_documentos')

    def __init__(self):
        self.mensaje = XmlField('MensajeConsultaSolicitudReposicion',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.solicitud_reposicion = SolicitudReposicionConsulta()
        self.direccion_ps = DireccionPS()
        self.registros_documentos = RegistrosDocumento()
        super(MensajeConsultaSolicitudReposicion, self).__init__('MensajeConsultaSolicitudReposicion', 'mensaje')


class SolicitudReposicionConsulta(XmlModel):

    _sort_order = ('solicitud_reposicion_consulta', 'codigo_de_solicitud_ref',
                   'tipo_de_reposicion', 'fecha_prevista_accion', 'actuacion_campo')

    def __init__(self):
        self.solicitud_reposicion_consulta = XmlField('SolicitudReposicion')
        self.codigo_de_solicitud_ref = XmlField('CodigoDeSolicitudRef')
        self.tipo_de_reposicion = XmlField('TipoDeReposicion')
        self.fecha_prevista_accion = XmlField('FechaPrevistaAccion')
        self.actuacion_campo = XmlField('ActuacionCampo')

        super(SolicitudReposicionConsulta, self).__init__('SolicitudReposicionConsulta',
                                                          'solicitud_reposicion_consulta')

# Paso 15

class MensajeAceptacionReposicionReceptor(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'aceptacion_reposicion_receptor')

    def __init__(self):
        self.mensaje = XmlField('MensajeAceptacionReposicionReceptor',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.aceptacion_reposicion_receptor = AceptacionReposicionReceptor()
        super(MensajeAceptacionReposicionReceptor, self).__init__('MensajeAceptacionReposicionReceptor', 'mensaje')


class AceptacionReposicionReceptor(XmlModel):

    _sort_order = ('aceptacion_reposicion_receptor', 'aceptacion_reposicion')

    def __init__(self):
        self.aceptacion_reposicion_receptor = XmlField('AceptacionReposicionReceptor')
        self.aceptacion_reposicion = XmlField('AceptacionReposicion')
        super(AceptacionReposicionReceptor, self).__init__('AceptacionReposicionReceptor', 'aceptacion_reposicion_receptor')

class MensajeRechazoReposicionReceptor(XmlModel):

    _sort_order = ('mensaje_rechazo', 'cabecera', 'rechazos',
                   'registros_documentos')

    def __init__(self):
        self.mensaje_rechazo = XmlField('MensajeRechazoReposicionReceptor',
                                        attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.rechazos = Rechazos()
        self.registros_documentos = RegistrosDocumento()
        super(MensajeRechazoReposicionReceptor, self).__init__('MensajeRechazoReposicionReceptor', 'mensaje_rechazo')


class Rechazos(XmlModel):

    _sort_order = ('rechazos', 'fecha_rechazo', 'rechazo_list')

    def __init__(self):
        self.rechazos = XmlField('Rechazos')
        self.fecha_rechazo = XmlField('FechaRechazo')
        self.rechazo_list = []
        super(Rechazos, self).__init__('Rechazos', 'rechazos')


# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from .message import Message
from .Deadlines import ProcessDeadline
from gestionatr.input.messages import except_f1
from gestionatr.utils import get_rec_attr


class A1(Message, ProcessDeadline):
    """Clase que implementa A1."""

    # Sobreescribim funcions relacionades amb la capçalera del XML
    @property
    def get_codi_emisor(self):
        if self.tipus == 'A1' and self.pas == '01':
            ref = self.head.CodigoEmpresaEmisora.text
        else:
            ref = self.head.CodigoREEEmpresaEmisora.text
        if not ref:
            raise except_f1('Error', u'Documento sin emisor')
        return ref

    @property
    def get_codi_destinatari(self):
        if self.tipus == 'A1' and self.pas == '02':
            ref = self.head.CodigoEmpresaDestino.text
        else:
            ref = self.head.CodigoREEEmpresaDestino.text
        if not ref:
            raise except_f1('Error', u'Documento sin emisor')
        return ref

    @property
    def cups(self):
        # El tipus A1 no informa CUPS a la capçalera
        return ''

    # Datos paso 01
    @property
    def movimiento(self):
        tree = '{0}.Movimiento'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def autoconsumo(self):
        tree = '{0}.Autoconsumo'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return Autoconsumo(data)
        else:
            return False

    @property
    def datos_suministro(self):
        data = []
        tree = get_rec_attr(self.obj, self._header, False)
        if hasattr(tree, 'DatosSuministro'):
            for datos in tree.DatosSuministro:
                data.append(DatosSuministro(datos))
            return data
        else:
            return False

    @property
    def datos_inst_gen(self):
        data = []
        tree = get_rec_attr(self.obj, self._header, False)
        if hasattr(tree, 'DatosInstGen'):
            for datos in tree.DatosInstGen:
                data.append(DatosInstGen(datos))
            return data
        else:
            return False

    @property
    def comentarios(self):
        tree = '{0}.Comentarios'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    # Datos paso 02 aceptacion / rechazo
    @property
    def cau(self):
        tree = '{0}.CAU'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    @property
    def rechazos(self):
        tree = '{0}.Rechazos'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return Rechazos(data)
        else:
            return False

    @property
    def comentarios(self):
        tree = '{0}.Comentarios'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False

    def check_minimum_fields(self):
        checker = MinimumFieldsChecker(self)
        return checker.check()


class Rechazos(object):

    def __init__(self, data):
        self.rechazos = data

    @property
    def fecha_rechazo(self):
        data = ''
        try:
            data = self.rechazos.FechaRechazo.text
        except AttributeError:
            pass
        return data

    @property
    def rechazo(self):
        data = []
        try:
            for rechazo in self.rechazos.Rechazo:
                data.append(Rechazo(rechazo))
        except AttributeError:
            pass
        return data


class Rechazo(object):

    def __init__(self, data):
        self.rechazo = data

    @property
    def secuencial(self):
        data = ''
        try:
            data = self.rechazo.Secuencial.text
        except AttributeError:
            pass
        return data

    @property
    def codigo_motivo(self):
        data = ''
        try:
            data = self.rechazo.CodigoMotivo.text
        except AttributeError:
            pass
        return data

    @property
    def comentarios(self):
        data = ''
        try:
            data = self.rechazo.Comentarios.text
        except AttributeError:
            pass
        return data

class Autoconsumo(object):

    def __init__(self, data):
        self.autoconsumo = data

    @property
    def cau(self):
        data = ''
        try:
            data = self.autoconsumo.CAU.text
        except AttributeError:
            pass
        return data

    @property
    def seccion_registro(self):
        data = ''
        try:
            data = self.autoconsumo.SeccionRegistro.text
        except AttributeError:
            pass
        return data

    @property
    def sub_seccion(self):
        data = ''
        try:
            data = self.autoconsumo.SubSeccion.text
        except AttributeError:
            pass
        return data

    @property
    def colectivo(self):
        data = ''
        try:
            data = self.autoconsumo.Colectivo.text
        except AttributeError:
            pass
        return data


class DatosSuministro(object):

    def __init__(self, data):
        self.datos_suministro = data

    @property
    def cups(self):
        data = ''
        try:
            data = self.datos_suministro.CUPS.text
        except AttributeError:
            pass
        return data

    @property
    def tipo_cups(self):
        data = ''
        try:
            data = self.datos_suministro.TipoCUPS.text
        except AttributeError:
            pass
        return data

    @property
    def ref_catastro(self):
        data = ''
        try:
            data = self.datos_suministro.RefCatastro.text
        except AttributeError:
            pass
        return data


class DatosInstGen(object):

    def __init__(self, data):
        self.datos_inst_gen = data

    @property
    def cil(self):
        data = ''
        try:
            data = self.datos_inst_gen.CIL.text
        except AttributeError:
            pass
        return data

    @property
    def tec_generador(self):
        data = ''
        try:
            data = self.datos_inst_gen.TecGenerador.text
        except AttributeError:
            pass
        return data

    @property
    def combustible(self):
        data = ''
        try:
            data = self.datos_inst_gen.Combustible.text
        except AttributeError:
            pass
        return data

    @property
    def pot_instalada_gen(self):
        data = ''
        try:
            data = self.datos_inst_gen.PotInstaladaGen.text
        except AttributeError:
            pass
        return data

    @property
    def tipo_instalacion(self):
        data = ''
        try:
            data = self.datos_inst_gen.TipoInstalacion.text
        except AttributeError:
            pass
        return data

    @property
    def esquema_medida(self):
        data = ''
        try:
            data = self.datos_inst_gen.EsquemaMedida.text
        except AttributeError:
            pass
        return data

    @property
    def ssaa(self):
        data = ''
        try:
            data = self.datos_inst_gen.SSAA.text
        except AttributeError:
            pass
        return data

    @property
    def ref_catastro(self):
        data = ''
        try:
            data = self.datos_inst_gen.RefCatastro.text
        except AttributeError:
            pass
        return data

    @property
    def utm(self):
        data = ''
        try:
            data = UTM(self.datos_inst_gen.UTM)
        except AttributeError:
            pass
        return data

    @property
    def titular_representante_gen(self):
        data = ''
        try:
            data = TitularRepresentanteGen(self.datos_inst_gen.TitularRepresentanteGen)
        except AttributeError:
            pass
        return data


class TitularRepresentanteGen(object):

    def __init__(self, data):
        self.titular_representante_gen = data

    @property
    def id_titular(self):
        data = ''
        try:
            data = IdTitular(self.titular_representante_gen.IdTitular)
        except AttributeError:
            pass
        return data

    @property
    def nombre(self):
        data = ''
        try:
            data = Nombre(self.titular_representante_gen.Nombre)
        except AttributeError:
            pass
        return data

    @property
    def telefono(self):
        data = []
        try:
            for telefono in self.titular_representante_gen.Telefono:
                data.append((telefono.PrefijoPais.text, telefono.Numero.text))
        except AttributeError:
            pass
        return data

    @property
    def correo_electronico(self):
        data = ''
        try:
            data = self.titular_representante_gen.CorreoElectronico.text
        except AttributeError:
            pass
        return data

    @property
    def direccion(self):
        data = ''
        try:
            data = Direccion(self.titular_representante_gen.Direccion)
        except AttributeError:
            pass
        return data


class IdTitular(object):

    def __init__(self, data):
        self.id_titular = data

    @property
    def tipo_identificador(self):
        data = ''
        try:
            data = self.id_titular.TipoIdentificador.text
        except AttributeError:
            pass
        return data

    @property
    def identificador(self):
        data = ''
        try:
            data = self.id_titular.Identificador.text
        except AttributeError:
            pass
        return data


class Nombre(object):

    def __init__(self, data):
        self.nombre = data

    @property
    def nombre_de_pila(self):
        data = ''
        try:
            data = self.nombre.NombreDePila.text
        except AttributeError:
            pass
        return data

    @property
    def primer_apellido(self):
        data = ''
        try:
            data = self.nombre.PrimerApellido.text
        except AttributeError:
            pass
        return data

    @property
    def segundo_apellido(self):
        data = ''
        try:
            data = self.nombre.SegundoApellido.text
        except AttributeError:
            pass
        return data

    @property
    def razon_social(self):
        data = ''
        try:
            data = self.nombre.RazonSocial.text
        except AttributeError:
            pass
        return data


class UTM(object):

    def __init__(self, data):
        self.utm = data

    @property
    def x(self):
        data = ''
        try:
            data = self.utm.X.text
        except AttributeError:
            pass
        return data

    @property
    def y(self):
        data = ''
        try:
            data = self.utm.Y.text
        except AttributeError:
            pass
        return data

    @property
    def huso(self):
        data = ''
        try:
            data = self.utm.Huso.text
        except AttributeError:
            pass
        return data

    @property
    def banda(self):
        data = ''
        try:
            data = self.utm.Banda.text
        except AttributeError:
            pass
        return data


class Direccion(object):

    def __init__(self, data):
        self.direccion = data

    @property
    def pais(self):
        data = ''
        try:
            data = self.direccion.Pais.text.strip()
        except AttributeError:
            pass
        return data

    @property
    def provincia(self):
        data = ''
        try:
            data = self.direccion.Provincia.text.strip()
        except AttributeError:
            pass
        return data

    @property
    def municipio(self):
        data = ''
        try:
            data = self.direccion.Municipio.text.strip()
        except AttributeError:
            pass
        return data

    @property
    def poblacion(self):
        data = ''
        try:
            data = self.direccion.Poblacion.text.strip()
        except AttributeError:
            pass
        return data

    @property
    def cod_postal(self):
        data = ''
        try:
            data = self.direccion.CodPostal.text.strip()
        except AttributeError:
            pass
        return data

    @property
    def tipo_via(self):
        data = ''
        try:
            data = self.direccion.Via.TipoVia.text.strip()
        except AttributeError:
            try:
                data = self.direccion.TipoVia.text.strip()
            except AttributeError:
                pass
        return data

    @property
    def calle(self):
        data = ''
        try:
            data = self.direccion.Via.Calle.text.strip()
        except AttributeError:
            try:
                data = self.direccion.Calle.text.strip()
            except AttributeError:
                pass
        return data

    @property
    def numero_finca(self):
        data = ''
        try:
            data = self.direccion.Via.NumeroFinca.text.strip()
        except AttributeError:
            try:
                data = self.direccion.NumeroFinca.text.strip()
            except AttributeError:
                pass
        return data

    @property
    def duplicador_finca(self):
        data = ''
        try:
            data = self.direccion.Via.DuplicadorFinca.text.strip()
        except AttributeError:
            try:
                data = self.direccion.DuplicadorFinca.text.strip()
            except AttributeError:
                pass
        return data

    @property
    def escalera(self):
        data = ''
        try:
            data = self.direccion.Via.Escalera.text.strip()
        except AttributeError:
            try:
                data = self.direccion.Escalera.text.strip()
            except AttributeError:
                pass
        return data

    @property
    def piso(self):
        data = ''
        try:
            data = self.direccion.Via.Piso.text.strip()
        except AttributeError:
            try:
                data = self.direccion.Piso.text.strip()
            except AttributeError:
                pass
        return data

    @property
    def puerta(self):
        data = ''
        try:
            data = self.direccion.Via.Puerta.text.strip()
        except AttributeError:
            try:
                data = self.direccion.Puerta.text.strip()
            except AttributeError:
                pass
        return data

    @property
    def tipo_aclarador_finca(self):
        data = ''
        try:
            data = self.direccion.Via.TipoAclaradorFinca.text.strip()
        except AttributeError:
            try:
                data = self.direccion.TipoAclaradorFinca.text.strip()
            except AttributeError:
                pass
        return data

    @property
    def aclarador_finca(self):
        data = ''
        try:
            data = self.direccion.Via.AclaradorFinca.text.strip()
        except AttributeError:
            try:
                data = self.direccion.AclaradorFinca.text.strip()
            except AttributeError:
                pass
        return data

    @property
    def apartado_de_correos(self):
        data = ''
        try:
            data = self.direccion.ApartadoDeCorreos.text.strip()
        except AttributeError:
            pass
        return data


class MinimumFieldsChecker(object):

    def __init__(self, a1):
        self.a1 = a1

    def check(self):
        errors = []

        for field in self.get_minimum_fields(pas=self.a1.pas):
            valid = getattr(self, 'check_{0}'.format(field), None)
            if not valid():
                errors.append(field)
        return errors

    def get_minimum_fields(self, pas='01'):
        if pas == '01':
            return [
                'moviment', 'cau', 'seccio_registre', 'collectiu', 'cups', 'tec_generador',
                'pot_installada_gen', 'tipus_installacio', 'ssaa', 'nom_titular', 'tipus_identificador',
                'identificador', 'telefon', 'pais', 'provincia', 'municipi', 'codi_postal', 'via_or_apartat_correus'
            ]
        elif pas == '02':
            return ['cau']
        else:
            return False

    def check_moviment(self):
        return get_rec_attr(self.a1, "movimiento", False)

    def check_cau(self):
        return get_rec_attr(self.a1, "autoconsumo.cau", False)

    def check_seccio_registre(self):
        return get_rec_attr(self.a1, "autoconsumo.seccion_registro", False)

    def check_collectiu(self):
        return get_rec_attr(self.a1, "autoconsumo.colectivo", False)

    def check_cups(self):
        valid = True
        for datos in self.a1.datos_suministro:
            valid = valid and get_rec_attr(datos, "cups", False)
        return valid

    def check_tec_generador(self):
        valid = True
        for datos in self.a1.datos_inst_gen:
            valid = valid and get_rec_attr(datos, "tec_generador", False)
        return valid

    def check_pot_installada_gen(self):
        valid = True
        for datos in self.a1.datos_inst_gen:
            valid = valid and get_rec_attr(datos, "pot_instalada_gen", False)
        return valid

    def check_tipus_installacio(self):
        valid = True
        for datos in self.a1.datos_inst_gen:
            valid = valid and get_rec_attr(datos, "tipo_instalacion", False)
        return valid

    def check_ssaa(self):
        valid = True
        for datos in self.a1.datos_inst_gen:
            valid = valid and get_rec_attr(datos, "ssaa", False)
        return valid

    def check_nom_titular(self):
        valid = True
        if self.a1.autoconsumo.seccion_registro == '2':
            for datos in self.a1.datos_inst_gen:
                nom = datos.titular_representante_gen.nombre
                check = get_rec_attr(nom, "nombre_de_pila", False) and \
                        get_rec_attr(nom, "primer_apellido", False) or \
                        get_rec_attr(nom, "razon_social", False)
                valid = valid and check
        return valid

    def check_tipus_identificador(self):
        valid = True
        if self.a1.autoconsumo.seccion_registro == '2':
            for datos in self.a1.datos_inst_gen:
                valid = valid and get_rec_attr(datos.titular_representante_gen.id_titular, "tipo_identificador", False)
        return valid

    def check_identificador(self):
        valid = True
        if self.a1.autoconsumo.seccion_registro == '2':
            for datos in self.a1.datos_inst_gen:
                valid = valid and get_rec_attr(datos.titular_representante_gen.id_titular, "identificador", False)
        return valid

    def check_telefon(self):
        valid = True
        if self.a1.autoconsumo.seccion_registro == '2':
            for datos in self.a1.datos_inst_gen:
                telefon = get_rec_attr(datos.titular_representante_gen, "telefono", False)
                if not telefon:
                    return False
                valid = valid and len(telefon) > 0
        return valid

    def check_pais(self):
        valid = True
        if self.a1.autoconsumo.seccion_registro == '2':
            for datos in self.a1.datos_inst_gen:
                direccio = datos.titular_representante_gen.direccion
                valid = valid and get_rec_attr(direccio, "pais", False)
        return valid

    def check_provincia(self):
        valid = True
        if self.a1.autoconsumo.seccion_registro == '2':
            for datos in self.a1.datos_inst_gen:
                direccio = datos.titular_representante_gen.direccion
                valid = valid and get_rec_attr(direccio, "provincia", False)
        return valid

    def check_municipi(self):
        valid = True
        if self.a1.autoconsumo.seccion_registro == '2':
            for datos in self.a1.datos_inst_gen:
                direccio = datos.titular_representante_gen.direccion
                valid = valid and get_rec_attr(direccio, "municipio", False)
        return valid

    def check_codi_postal(self):
        valid = True
        if self.a1.autoconsumo.seccion_registro == '2':
            for datos in self.a1.datos_inst_gen:
                direccio = datos.titular_representante_gen.direccion
                valid = valid and get_rec_attr(direccio, "cod_postal", False)
        return valid

    def check_via_or_apartat_correus(self):
        valid = True
        if self.a1.autoconsumo.seccion_registro == '2':
            for datos in self.a1.datos_inst_gen:
                direccio = datos.titular_representante_gen.direccion
                has_apartado_correos = get_rec_attr(direccio, "apartado_de_correos", False)
                has_via = get_rec_attr(direccio, "tipo_via", False) and \
                          get_rec_attr(direccio, "calle", False) and \
                          get_rec_attr(direccio, "numero_finca", False)
                valid = valid and (has_apartado_correos or has_via)
        return valid



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from .message_gas import MessageGas
from .Deadlines import ProcessDeadline, DeadLine, Workdays, Naturaldays
from gestionatr.utils import get_rec_attr
from .A12_26 import *


class A19_45(A12_26):

    steps = []

    @property
    def countertype(self):
        tree = '{0}.countertype'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def inspectionorig(self):
        tree = '{0}.inspectionorig'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def counternumber(self):
        tree = '{0}.counternumber'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def counterproperty(self):
        tree = '{0}.counterproperty'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def reallecture(self):
        tree = '{0}.reallecture'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def counterpressure(self):
        tree = '{0}.counterpressure'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from libcomxml.core import XmlModel, XmlField

from gestionatr.output.messages.base import CabeceraAutoconsumo, CabeceraAutoconsumoRechazo


# Paso 01
class A101(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'info_registro_autocons')

    def __init__(self):
        self.mensaje = XmlField('A101',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = CabeceraAutoconsumo()
        self.info_registro_autocons = InfoRegistroAutoconsA1()
        super(A101, self).__init__('A101', 'mensaje')


class InfoRegistroAutoconsA1(XmlModel):

    _sort_order = ('info_registro_autocons', 'movimiento', 'autoconsumo', 'datos_suministro', 'datos_inst_gen',
                   'comentarios')

    def __init__(self):
        self.info_registro_autocons = XmlField('A101')
        self.movimiento = XmlField('Movimiento')
        self.autoconsumo = Autoconsumo()
        self.datos_suministro = DatosSuministro()
        self.datos_inst_gen = DatosInstGen()
        self.comentarios = XmlField('Comentarios')
        super(InfoRegistroAutoconsA1, self).__init__('InfoRegistoAutoconsA1', 'info_registro_autocons')


# Paso 02
class MensajeA102(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'a102')

    def __init__(self):
        self.mensaje = XmlField('A102',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = CabeceraAutoconsumoRechazo()
        self.a102 = A102()
        super(MensajeA102, self).__init__('A102', 'mensaje')


class A102(XmlModel):

    _sort_order = ('a102', 'cau', 'rechazos', 'comentarios')

    def __init__(self):
        self.a102 = XmlField('A102')
        self.cau = XmlField('CAU')
        self.rechazos = Rechazos()
        self.comentarios = XmlField('Comentarios')
        super(A102, self).__init__('A102', 'a102')


class Rechazos(XmlModel):

    _sort_order = ('rechazos', 'fecha_rechazo', 'rechazo_list')

    def __init__(self):
        self.rechazos = XmlField('Rechazos')
        self.fecha_rechazo = XmlField('FechaRechazo')
        self.rechazo_list = []
        super(Rechazos, self).__init__('Rechazos', 'rechazos')


class Rechazo(XmlModel):

    _sort_order = ('rechazo', 'secuencial', 'codigo_motivo', 'comentarios')

    def __init__(self):
        self.rechazo = XmlField('Rechazo')
        self.secuencial = XmlField('Secuencial')
        self.codigo_motivo = XmlField('CodigoMotivo')
        self.comentarios = XmlField('Comentarios')
        super(Rechazo, self).__init__('Rechazo', 'rechazo')


class Autoconsumo(XmlModel):

    _sort_order = ('autoconsumo', 'cau', 'seccion_registro', 'sub_seccion', 'colectivo')

    def __init__(self):
        self.autoconsumo = XmlField('Autoconsumo')
        self.cau = XmlField('CAU')
        self.seccion_registro = XmlField('SeccionRegistro')
        self.sub_seccion = XmlField('SubSeccion')
        self.colectivo = XmlField('Colectivo')
        super(Autoconsumo, self).__init__('Autoconsumo', 'autoconsumo')


class DatosSuministro(XmlModel):

    _sort_order = ('datos_suministro', 'cups', 'tipo_cups', 'ref_catastro')

    def __init__(self):
        self.datos_suministro = XmlField('DatosSuministro')
        self.cups = XmlField('CUPS')
        self.tipo_cups = XmlField('TipoCUPS')
        self.ref_catastro = XmlField('RefCatastro')
        super(DatosSuministro, self).__init__('DatosSuministro', 'datos_suministro')


class DatosInstGen(XmlModel):

    _sort_order = ('datos_inst_gen', 'cil', 'tec_generador', 'combustible', 'pot_instalada_gen', 'tipo_instalacion',
                   'esquema_medida', 'ssaa', 'ref_catastro', 'utm', 'titular_representante_gen')

    def __init__(self):
        self.datos_inst_gen = XmlField('DatosInstGen')
        self.cil = XmlField('CIL')
        self.tec_generador = XmlField('TecGenerador')
        self.combustible = XmlField('Combustible')
        self.pot_instalada_gen = XmlField('PotInstaladaGen')
        self.tipo_instalacion = XmlField('TipoInstalacion')
        self.esquema_medida = XmlField('EsquemaMedida')
        self.ssaa = XmlField('SSAA')
        self.ref_catastro = XmlField('RefCatastro')
        self.utm = UTM()
        self.titular_representante_gen = TitularRepresentanteGen()
        super(DatosInstGen, self).__init__('DatosInstGen', 'datos_inst_gen')


class UTM(XmlModel):

    _sort_order = ('utm', 'x', 'y', 'huso', 'banda')

    def __init__(self):
        self.utm = XmlField('UTM')
        self.x = XmlField('X')
        self.y = XmlField('Y')
        self.huso = XmlField('Huso')
        self.banda = XmlField('Banda')
        super(UTM, self).__init__('UTM', 'utm')


class TitularRepresentanteGen(XmlModel):

    _sort_order = ('titular_representante_gen', 'id_titular', 'nombre', 'telefono', 'correo_electronico',
                   'direccion')

    def __init__(self):
        self.titular_representante_gen = XmlField('TitularRepresentanteGen')
        self.id_titular = IdTitular()
        self.nombre = Nombre()
        self.telefono = Telefono()
        self.correo_electronico = XmlField('CorreoElectronico')
        self.direccion = Direccion()
        super(TitularRepresentanteGen, self).__init__('TitularRepresentanteGen', 'titular_representante_gen')


class IdTitular(XmlModel):

    _sort_order = ('id_titular', 'tipo_identificador', 'identificador')

    def __init__(self):
        self.id_titular = XmlField('IdTitular')
        self.tipo_identificador = XmlField('TipoIdentificador')
        self.identificador = XmlField('Identificador')
        super(IdTitular, self).__init__('IdTitular', 'id_titular')


class Nombre(XmlModel):

    _sort_order = ('nombre', 'nombre_de_pila', 'primer_apellido', 'segundo_apellido', 'razon_social')

    def __init__(self):
        self.nombre = XmlField('Nombre')
        self.nombre_de_pila = XmlField('NombreDePila')
        self.primer_apellido = XmlField('PrimerApellido')
        self.segundo_apellido = XmlField('SegundoApellido')
        self.razon_social = XmlField('RazonSocial')
        super(Nombre, self).__init__('Nombre', 'nombre')


class Telefono(XmlModel):

    _sort_order = ('telefono', 'prefijo_pais', 'numero')

    def __init__(self):
        self.telefono = XmlField('Telefono')
        self.prefijo_pais = XmlField('PrefijoPais')
        self.numero = XmlField('Numero')
        super(Telefono, self).__init__('Telefono', 'telefono')


class Direccion(XmlModel):

    _sort_order = ('direccion', 'pais', 'provincia', 'municipio', 'poblacion', 'cod_postal', 'via',
                   'apartado_de_correos')

    def __init__(self):
        self.direccion = XmlField('Direccion')
        self.pais = XmlField('Pais')
        self.provincia = XmlField('Provincia')
        self.municipio = XmlField('Municipio')
        self.poblacion = XmlField('Poblacion')
        self.cod_postal = XmlField('CodPostal')
        self.via = Via()
        self.apartado_de_correos = XmlField('ApartadoDeCorreos')
        super(Direccion, self).__init__('Direccion', 'direccion')


class Via(XmlModel):

    _sort_order = ('via', 'tipo_via', 'calle', 'numero_finca', 'duplicador_finca', 'escalera', 'piso', 'puerta',
                   'tipo_aclarador_finca', 'aclarador_finca')

    def __init__(self):
        self.via = XmlField('Via')
        self.tipo_via = XmlField('TipoVia')
        self.calle = XmlField('Calle')
        self.numero_finca = XmlField('NumeroFinca')
        self.duplicador_finca = XmlField('DuplicadorFinca')
        self.escalera = XmlField('Escalera')
        self.piso = XmlField('Piso')
        self.puerta = XmlField('Puerta')
        self.tipo_aclarador_finca = XmlField('TipoAclaradorFinca')
        self.aclarador_finca = XmlField('AclaradorFinca')
        super(Via, self).__init__('Via', 'via')



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from .C2 import C2, DatosSolicitud
from .Deadlines import ProcessDeadline, DeadLine, Workdays, Naturaldays
from gestionatr.utils import get_rec_attr


class M1(C2):
    """Classe que implementa M1."""

    steps_T = [
        DeadLine('01', Workdays(5)),
        DeadLine('02', Workdays(1)),
        DeadLine('03', Naturaldays(30)),
        DeadLine('05', Workdays(1)),
        DeadLine('06', Workdays(5)),
    ]

    steps_S = [
        DeadLine('01', Workdays(5)),
        DeadLine('02', Workdays(5)),
        DeadLine('06', Workdays(5)),
    ]
    steps_A = steps_S
    steps_C = steps_S

    steps_P = steps_T

    steps = steps_T

    # Datos paso 01
    @property
    def datos_solicitud(self):
        tree = '{0}.DatosSolicitud'.format(self._header)
        sol = get_rec_attr(self.obj, tree, False)
        if sol not in [None, False]:
            return DatosSolicitud(sol)
        else:
            return False


class DatosSolicitud(DatosSolicitud):

    @property
    def periodicidad_facturacion(self):
        data = ''
        try:
            data = self.datos_solicitud.PeriodicidadFacturacion.text
        except AttributeError:
            pass
        return data


# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from gestionatr.utils import get_rec_attr
from .A1_44 import A1_44


class A1_04(A1_44):
    """Clase que implementa A1_44."""
    @property
    def cancelreason(self):
        tree = '{0}.cancelreason'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def moreinformation(self):
        tree = '{0}.moreinformation'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from .E1 import E1, DatosActivacion, DatosNotificacion
from .C2 import Direccion
from .C1 import RegistroDoc
from gestionatr.utils import get_rec_attr


class E2(E1):
    """Classe que implementa E2."""

    # Datos paso 01

    @property
    def tipo_de_reposicion(self):
        tree = '{0}.TipoDeReposicion'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False


    @property
    def datos_notificacion(self):
        tree = '{0}.DatosNotificacion'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return DatosNotificacion(data)
        else:
            return False

    @property
    def datos_activacion(self):
        tree = '{0}.DatosActivacion'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return DatosActivacion(data)
        else:
            return False

    # Dades de E214
    @property
    def solicitud_reposicion(self):
        tree = 'SolicitudReposicion'
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return SolicitudReposicion(data)
        else:
            return False

    @property
    def direccion_ps(self):
        tree = 'DireccionPS'
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return Direccion(data)
        else:
            return False

    @property
    def registros_documento(self):
        data = []
        obj = get_rec_attr(self.obj, self._header, False)
        if (hasattr(obj, 'RegistrosDocumento') and
                hasattr(obj.RegistrosDocumento, 'RegistroDoc')):
            for d in obj.RegistrosDocumento.RegistroDoc:
                data.append(RegistroDoc(d))
        return data

    @property
    def aceptacion_reposicion(self):
        tree = '{0}.AceptacionReposicion'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data:
            return data.text
        else:
            return False


class DatosNotificacion(DatosNotificacion):

    @property
    def codigo_sol_corte(self):
        data = ''
        try:
            data = self.datos_notificacion.CodigoSolCorte.text
        except AttributeError:
            pass
        return data

    @property
    def ind_esencial(self):
        data = ''
        try:
            data = self.datos_notificacion.IndEsencial.text
        except AttributeError:
            pass
        return data

    @property
    def fecha_ultimo_movimiento_ind_esencial(self):
        data = False
        try:
            data = self.datos_notificacion.FechaUltimoMovimientoIndEsencial.text
        except AttributeError:
            pass
        return data


class DatosActivacion(DatosActivacion):
    @property
    def resultado_activacion(self):
        data = False
        try:
            data = self.datos_activacion.ResultadoActivacion.text
        except AttributeError:
            pass
        return data


# Dades del pas 14
class SolicitudReposicion(object):

    def __init__(self, data):
        self.solicitud_reposicion = data

    @property
    def codigo_de_solicitud_ref(self):
        data = False
        try:
            data = self.solicitud_reposicion.CodigoDeSolicitudRef.text
        except AttributeError:
            pass
        return data

    @property
    def tipo_de_reposicion(self):
        data = False
        try:
            data = self.solicitud_reposicion.TipoDeReposicion.text
        except AttributeError:
            pass
        return data

    @property
    def fecha_prevista_accion(self):
        data = False
        try:
            data = self.solicitud_reposicion.FechaPrevistaAccion.text
        except AttributeError:
            pass
        return data

    @property
    def actuacion_campo(self):
        data = False
        try:
            data = self.solicitud_reposicion.ActuacionCampo.text
        except AttributeError:
            pass
        return data


# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from .A1_41 import *
from gestionatr.utils import get_rec_attr


class A1_02(A1_41):
    """Clase que implementa C1."""

    steps = []

    # Datos paso a102
    # TODO

    # Datos paso a202
    @property
    def outgoingpressuregranted(self):
        tree = '{0}.outgoingpressuregranted'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return data.text
        else:
            return False

    # Datos paso a302
    @property
    def caecode(self):
        tree = '{0}.caecode'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data not in [None, False]:
            return data.text
        else:
            return False

    # Paso a3s02 ya soportado con los datos que tenemos
    # Paso a402 ya soportado con los datos que tenemos



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from libcomxml.core import XmlModel, XmlField
from gestionatr.output.messages.base_gas import Heading
from .sw_a1_41 import Registerdoc, Registerdoclist


# Paso 01
class MensajeA2542(XmlModel):
    _sort_order = ('mensaje', 'heading', 'a2542')

    def __init__(self):
        self.doc_root = None
        self.mensaje = XmlField(
            'sctdapplication', attributes={'xmlns': 'http://localhost/sctd/A2542'}
        )
        self.heading = Heading()
        self.a2542 = A2542()
        super(MensajeA2542, self).__init__('sctdapplication', 'mensaje')


class A2542(XmlModel):

    _sort_order = (
        'a2542',
        'reqcode',
        'cups',
        'visitdate',
        'visithour',
        'comreferencenum',
        'informationtype',
        'informationtypedesc',
        'interventiondate',
        'interventionhourfrom',
        'interventionhourto',
        'visitnumber',
        'operationnum',
        'extrainfo',
        'defectlist',
    )

    def __init__(self):
        self.a2542 = XmlField('a2542')
        self.reqcode = XmlField('reqcode')
        self.cups = XmlField('cups')
        self.visitdate = XmlField('visitdate')
        self.visithour = XmlField('visithour')
        self.comreferencenum = XmlField('comreferencenum')
        self.informationtype = XmlField('informationtype')
        self.informationtypedesc = XmlField('informationtypedesc')
        self.interventiondate = XmlField('interventiondate')
        self.interventionhourfrom = XmlField('interventionhourfrom')
        self.interventionhourto = XmlField('interventionhourto')
        self.visitnumber = XmlField('visitnumber')
        self.operationnum = XmlField('operationnum')
        self.extrainfo = XmlField('extrainfo')
        self.defectlist = Defectlist()
        super(A2542, self).__init__('a2542', 'a2542')


class Defectlist(XmlModel):

    _sort_order = ('defectlist', 'defect_list')

    def __init__(self):
        self.defectlist = XmlField('defectlist')
        self.defect_list = []
        super(Defectlist, self).__init__('defectlist', 'defectlist')


class Defect(XmlModel):

    _sort_order = ('defect', 'code', 'description',)

    def __init__(self):
        self.defect = XmlField('defect')
        self.code = XmlField('code')
        self.description = XmlField('description')
        super(Defect, self).__init__('defect', 'defect')



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from libcomxml.core import XmlModel, XmlField
from gestionatr.output.messages.base import Cabecera
from gestionatr.output.messages.sw_c1 import Autoconsumo


# Paso 01
class MensajeNotificacionCambiosATRDesdeDistribuidor(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'notificacion_cambios_atr_desde_distribuidor')

    def __init__(self):
        self.mensaje = XmlField('MensajeNotificacionCambiosATRDesdeDistribuidor',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.notificacion_cambios_atr_desde_distribuidor = []
        super(MensajeNotificacionCambiosATRDesdeDistribuidor, self) \
            .__init__('MensajeNotificacionCambiosATRDesdeDistribuidor', 'mensaje')


class NotificacionCambiosATRDesdeDistribuidor(XmlModel):

    _sort_order = ('notificacion_cambios_atr_desde_distribuidor', 'motivo_cambio_atr_desde_distribuidora',
                   'fecha_prevista_aplicacion_cambio_atr', 'fecha_maxima_rechazo', 'periodicidad_facturacion',
                   'ind_esencial', 'fecha_ultimo_movimiento_ind_esencial', 'info_registro_autocons',
                   'info_retardo_activ_autocons_list', 'registros_documento')

    def __init__(self):
        self.notificacion_cambios_atr_desde_distribuidor = XmlField('NotificacionCambiosATRDesdeDistribuidor')
        self.motivo_cambio_atr_desde_distribuidora = XmlField('MotivoCambioATRDesdeDistribuidora')
        self.fecha_prevista_aplicacion_cambio_atr = XmlField('FechaPrevistaAplicacionCambioATR')
        self.fecha_maxima_rechazo = XmlField('FechaMaximaRechazo')
        self.periodicidad_facturacion = XmlField('PeriodicidadFacturacion')
        self.ind_esencial = XmlField('IndEsencial')
        self.fecha_ultimo_movimiento_ind_esencial = XmlField('FechaUltimoMovimientoIndEsencial')
        self.info_registro_autocons = InfoRegistroAutocons()
        self.info_retardo_activ_autocons_list = []
        self.registros_documento = RegistrosDocumento()
        super(NotificacionCambiosATRDesdeDistribuidor, self).__init__('NotificacionCambiosATRDesdeDistribuidor',
                                                                      'notificacion_cambios_atr_desde_distribuidor')


class InfoRegistroAutocons(XmlModel):

    _sort_order = ('info_registro_autocons', 'autoconsumo')

    def __init__(self):
        self.info_registro_autocons = XmlField('InfoRegistroAutocons')
        self.autoconsumo = Autoconsumo()
        super(InfoRegistroAutocons, self).__init__('InfoRegistroAutocons', 'info_registro_autocons')

class InfoRetardoActivAutocons(XmlModel):

    _sort_order = ('info_retardo_activ_autocons', 'codigo_fiscal_factura', 'fecha_inicio_conteo_activ_autocons',
                   'fecha_desde', 'fecha_hasta', 'dias_retardo_activ_autocons', 'valor_energia_anual_calculada',
                   'valor_energia_horaria_calculada', 'pot_instalada_gen')
    def __init__(self):
        self.info_retardo_activ_autocons = XmlField('InfoRetardoActivAutocons')
        self.codigo_fiscal_factura = XmlField('CodigoFiscalFactura')
        self.fecha_inicio_conteo_activ_autocons = XmlField('FechaInicioConteoActivAutocons')
        self.fecha_desde = XmlField('FechaDesde')
        self.fecha_hasta = XmlField('FechaHasta')
        self.dias_retardo_activ_autocons = XmlField('DiasRetardoActivAutocons')
        self.valor_energia_anual_calculada = XmlField('ValorEnergiaAnualCalculada')
        self.valor_energia_horaria_calculada = XmlField('ValorEnergiaHorariaCalculada')
        self.pot_instalada_gen = XmlField('PotInstaladaGen')
        super(InfoRetardoActivAutocons, self).__init__('InfoRetardoActivAutocons', 'info_retardo_activ_autocons')


# Paso 02 (Rechazo)
class MensajeRechazo(XmlModel):

    _sort_order = ('mensaje_rechazo', 'cabecera', 'rechazos')

    def __init__(self):
        self.mensaje_rechazo = XmlField('MensajeRechazoD1',
                                        attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.rechazos = Rechazos()
        super(MensajeRechazo, self).__init__('MensajeRechazo', 'mensaje_rechazo')


class Rechazos(XmlModel):

    _sort_order = ('rechazos', 'fecha_rechazo', 'rechazo', 'registros_documento')

    def __init__(self):
        self.rechazos = XmlField('Rechazos')
        self.fecha_rechazo = XmlField('FechaRechazo')
        self.rechazo = Rechazo()
        self.registros_documento = RegistrosDocumento()
        super(Rechazos, self).__init__('Rechazos', 'rechazos')


class Rechazo(XmlModel):

    _sort_order = ('rechazo', 'secuencial', 'codigo_motivo', 'comentarios')

    def __init__(self):
        self.rechazo = XmlField('Rechazo')
        self.secuencial = XmlField('Secuencial')
        self.codigo_motivo = XmlField('CodigoMotivo')
        self.comentarios = XmlField('Comentarios')
        super(Rechazo, self).__init__('Rechazo', 'rechazo')


class RegistrosDocumento(XmlModel):

    _sort_order = ('registros_documento', 'registro_doc')

    def __init__(self):
        self.registros_documento = XmlField('RegistrosDocumento')
        self.registro_doc = RegistroDoc()
        super(RegistrosDocumento, self).__init__('RegistrosDocumento', 'registros_documento')


class RegistroDoc(XmlModel):

    _sort_order = ('registro_doc', 'tipo_doc_aportado', 'direccion_url')

    def __init__(self):
        self.registro_doc = XmlField('RegistroDoc')
        self.tipo_doc_aportado = XmlField('TipoDocAportado')
        self.direccion_url = XmlField('DireccionUrl')
        super(RegistroDoc, self).__init__('RegistroDoc', 'registro_doc')


# Paso 10
class MensajeAnulacionD1(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'anulacion_notificacion_cambios_atr_desde_distribuidor')

    def __init__(self):
        self.mensaje = XmlField('MensajeAnulacionD1', attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.anulacion_notificacion_cambios_atr_desde_distribuidor = AnulacionNotificacionCambiosATRDesdeDistribuidor()
        super(MensajeAnulacionD1, self).__init__('MensajeAnulacionD1', 'mensaje')


class AnulacionNotificacionCambiosATRDesdeDistribuidor(XmlModel):

    _sort_order = ('anulacion_notificacion_cambios_atr_desde_distribuidor', 'datos_anulacion')

    def __init__(self):
        self.anulacion_notificacion_cambios_atr_desde_distribuidor = XmlField(
            'AnulacionNotificacionCambiosATRDesdeDistribuidor'
        )
        self.datos_anulacion = DatosAnulacion()
        super(AnulacionNotificacionCambiosATRDesdeDistribuidor, self).__init__(
            'AnulacionNotificacionCambiosATRDesdeDistribuidor', 'anulacion_notificacion_cambios_atr_desde_distribuidor'
        )


class DatosAnulacion(XmlModel):

    _sort_order = ('datos_anulacion', 'fecha_anulacion')

    def __init__(self):
        self.datos_anulacion = XmlField('DatosAnulacion')
        self.fecha_anulacion = XmlField('FechaAnulacion')
        super(DatosAnulacion, self).__init__('DatosAnulacion', 'datos_anulacion')



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from .A1_38 import *


class A20_36(A1_38):

    @property
    def solcode(self):
        tree = '{0}.solcode'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def resultdescr(self):
        tree = '{0}.resultdescr'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def reason(self):
        tree = '{0}.reason'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def reasondescr(self):
        tree = '{0}.reasondescr'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def permissionreq(self):
        tree = '{0}.permissionreq'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def expecteddate(self):
        tree = '{0}.expecteddate'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def infraestructurestatus(self):
        tree = '{0}.infraestructurestatus'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def comunitypressure(self):
        tree = '{0}.comunitypressure'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def aptransind(self):
        tree = '{0}.aptransind'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def aptransnumber(self):
        tree = '{0}.aptransnumber'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def reig(self):
        tree = '{0}.reig'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def iricertificateneeded(self):
        tree = '{0}.iricertificateneeded'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def iricertificatedate(self):
        tree = '{0}.iricertificatedate'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def designpower(self):
        tree = '{0}.designpower'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False

    @property
    def terminstexist(self):
        tree = '{0}.terminstexist'.format(self._header)
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from libcomxml.core import XmlModel, XmlField
from gestionatr.output.messages.base_gas import Heading


# Paso 01
class MensajeA141(XmlModel):
    _sort_order = ('mensaje', 'heading', 'a141')

    def __init__(self):
        self.doc_root = None
        self.mensaje = XmlField(
            'sctdapplication', attributes={'xmlns': 'http://localhost/sctd/A141'}
        )
        self.heading = Heading()
        self.a141 = A141()
        super(MensajeA141, self).__init__('sctdapplication', 'mensaje')


class A141(XmlModel):

    _sort_order = (
        'a141', 'comreferencenum', 'reqdate', 'reqhour', 'nationality',
        'documenttype', 'documentnum', 'cups', 'modeffectdate',
        'reqtransferdate', 'updatereason', 'surrogacy', 'newnationality',
        'newdocumenttype', 'newdocumentnum', 'newfirstname', 'newfamilyname1',
        'newfamilyname2', 'newtitulartype', 'newregularaddress',
        'newtelephone1', 'newtelephone2', 'newemail', 'newlanguage',
        'newprovinceowner', 'newcityowner', 'newzipcodeowner',
        'newstreettypeowner', 'newstreetowner', 'newstreetnumberowner',
        'newportal', 'newstaircase', 'newfloor', 'newdoor', 'newreqqd',
        'disconnectedserviceaccepted', 'readingvalue', 'cnae', 'protectedtype', 'essentialtype',
        'extrainfo', 'registerdoclist'
    )

    def __init__(self):
        self.a141 = XmlField('a141')
        self.comreferencenum = XmlField('comreferencenum')
        self.reqdate = XmlField('reqdate')
        self.reqhour = XmlField('reqhour')
        self.nationality = XmlField('nationality')
        self.documenttype = XmlField('documenttype')
        self.documentnum = XmlField('documentnum')
        self.cups = XmlField('cups')
        self.modeffectdate = XmlField('modeffectdate')
        self.reqtransferdate = XmlField('reqtransferdate')
        self.updatereason = XmlField('updatereason')
        self.surrogacy = XmlField('surrogacy')
        self.newnationality = XmlField('newnationality')
        self.newdocumenttype = XmlField('newdocumenttype')
        self.newdocumentnum = XmlField('newdocumentnum')
        self.newfirstname = XmlField('newfirstname')
        self.newfamilyname1 = XmlField('newfamilyname1')
        self.newfamilyname2 = XmlField('newfamilyname2')
        self.newtitulartype = XmlField('newtitulartype')
        self.newregularaddress = XmlField('newregularaddress')
        self.newtelephone1 = XmlField('newtelephone1')
        self.newtelephone2 = XmlField('newtelephone2')
        self.newemail = XmlField('newemail')
        self.newlanguage = XmlField('newlanguage')
        self.newprovinceowner = XmlField('newprovinceowner')
        self.newcityowner = XmlField('newcityowner')
        self.newzipcodeowner = XmlField('newzipcodeowner')
        self.newstreettypeowner = XmlField('newstreettypeowner')
        self.newstreetowner = XmlField('newstreetowner')
        self.newstreetnumberowner = XmlField('newstreetnumberowner')
        self.newportal = XmlField('newportal')
        self.newstaircase = XmlField('newstaircase')
        self.newfloor = XmlField('newfloor')
        self.newdoor = XmlField('newdoor')
        self.newreqqd = XmlField('newreqqd')
        self.disconnectedserviceaccepted = XmlField('disconnectedserviceaccepted')
        self.readingvalue = XmlField('readingvalue')
        self.cnae = XmlField('cnae')
        self.protectedtype = XmlField('protectedtype')
        self.essentialtype = XmlField('essentialtype')
        self.extrainfo = XmlField('extrainfo')
        self.registerdoclist = Registerdoclist()
        super(A141, self).__init__('a141', 'a141')


class Registerdoclist(XmlModel):

    _sort_order = ('registerdoclist', 'registerdoc_list')

    def __init__(self):
        self.registerdoclist = XmlField('registerdoclist')
        self.registerdoc_list = []
        super(Registerdoclist, self).__init__('registerdoclist', 'registerdoclist')


class Registerdoc(XmlModel):

    _sort_order = ('registerdoc', 'date', 'doctype', 'url', 'extrainfo')

    def __init__(self):
        self.registerdoc = XmlField('registerdoc')
        self.date = XmlField('date')
        self.doctype = XmlField('doctype')
        self.url = XmlField('url')
        self.extrainfo = XmlField('extrainfo')
        super(Registerdoc, self).__init__('registerdoc', 'registerdoc')



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from gestionatr.output.messages.sw_c1 import *


# Paso 01
class MensajeSolicitudAportacionLectura(XmlModel):

    _sort_order = ('mensaje', 'cabecera', 'datos_solicitud_aportacion_lectura', 'lectura_aportada_list')

    def __init__(self):
        self.mensaje = XmlField('MensajeSolicitudAportacionLectura',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.datos_solicitud_aportacion_lectura = DatosSolicitudAportacionLectura()
        self.lectura_aportada_list = []
        super(MensajeSolicitudAportacionLectura, self).__init__('MensajeSolicitudAportacionLectura', 'mensaje')


class DatosSolicitudAportacionLectura(XmlModel):

    _sort_order = ('datos_solicitud_aportacion_lectura', 'fecha_lectura', 'tipo_dhedm')

    def __init__(self):
        self.datos_solicitud_aportacion_lectura = XmlField('DatosSolicitudAportacionLectura')
        self.fecha_lectura = XmlField('FechaLectura')
        self.tipo_dhedm = XmlField('TipoDHEdM')
        super(DatosSolicitudAportacionLectura, self).__init__('DatosSolicitudAportacionLectura', 'datos_solicitud_aportacion_lectura')


class LecturaAportada(XmlModel):

    _sort_order = ('lectura_aportada', 'integrador', 'tipo_codigo_periodo_dh', 'lectura_propuesta')

    def __init__(self):
        self.lectura_aportada = XmlField('LecturaAportada')
        self.integrador = XmlField('Integrador')
        self.tipo_codigo_periodo_dh = XmlField('TipoCodigoPeriodoDH')
        self.lectura_propuesta = XmlField('LecturaPropuesta')
        super(LecturaAportada, self).__init__('LecturaAportada', 'lectura_aportada')


# Paso 02
class AceptacionAportacionLectura(XmlModel):
    _sort_order = (
    'aceptacion_aportacion_lectura', 'cabecera', 'datos_aceptacion_lectura')

    def __init__(self):
        self.mensaje = XmlField('AceptacionAportacionLectura',
                                attributes={'xmlns': 'http://localhost/elegibilidad'})
        self.cabecera = Cabecera()
        self.datos_aceptacion_lectura = DatosAceptacionLectura()
        super(AceptacionAportacionLectura, self).__init__('AceptacionAportacionLectura', 'mensaje')


class DatosAceptacionLectura(XmlModel):

    _sort_order = ('datos_aceptacion_lectura', 'fecha_aceptacion')

    def __init__(self):
        self.datos_aceptacion_lectura = XmlField('DatosAceptacionLectura')
        self.fecha_aceptacion = XmlField('FechaAceptacion')
        super(DatosAceptacionLectura, self).__init__('DatosAceptacionLectura', 'datos_aceptacion_lectura')
